# Autogenerated by get_module_idx.py

d = { 'settings': {'lib_path': 'nbdev_pandas'},
  'syms': { 'pandas': { 'pandas.ArrowDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.ArrowDtype.html#pandas.ArrowDtype',
                        'pandas.BooleanDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.BooleanDtype.html#pandas.BooleanDtype',
                        'pandas.Categorical': 'https://pandas.pydata.org/docs/reference/api/pandas.Categorical.html#pandas.Categorical',
                        'pandas.Categorical.__array__': 'https://pandas.pydata.org/docs/reference/api/pandas.Categorical.__array__.html#pandas.Categorical.__array__',
                        'pandas.Categorical.from_codes': 'https://pandas.pydata.org/docs/reference/api/pandas.Categorical.from_codes.html#pandas.Categorical.from_codes',
                        'pandas.CategoricalDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalDtype.html#pandas.CategoricalDtype',
                        'pandas.CategoricalIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.html#pandas.CategoricalIndex',
                        'pandas.CategoricalIndex.add_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.add_categories.html#pandas.CategoricalIndex.add_categories',
                        'pandas.CategoricalIndex.as_ordered': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.as_ordered.html#pandas.CategoricalIndex.as_ordered',
                        'pandas.CategoricalIndex.as_unordered': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.as_unordered.html#pandas.CategoricalIndex.as_unordered',
                        'pandas.CategoricalIndex.equals': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.equals.html#pandas.CategoricalIndex.equals',
                        'pandas.CategoricalIndex.map': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.map.html#pandas.CategoricalIndex.map',
                        'pandas.CategoricalIndex.remove_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.remove_categories.html#pandas.CategoricalIndex.remove_categories',
                        'pandas.CategoricalIndex.remove_unused_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.remove_unused_categories.html#pandas.CategoricalIndex.remove_unused_categories',
                        'pandas.CategoricalIndex.rename_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.rename_categories.html#pandas.CategoricalIndex.rename_categories',
                        'pandas.CategoricalIndex.reorder_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.reorder_categories.html#pandas.CategoricalIndex.reorder_categories',
                        'pandas.CategoricalIndex.set_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.set_categories.html#pandas.CategoricalIndex.set_categories',
                        'pandas.DataFrame': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.html#pandas.DataFrame',
                        'pandas.DataFrame.__add__': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.__add__.html#pandas.DataFrame.__add__',
                        'pandas.DataFrame.__dataframe__': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.__dataframe__.html#pandas.DataFrame.__dataframe__',
                        'pandas.DataFrame.__iter__': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.__iter__.html#pandas.DataFrame.__iter__',
                        'pandas.DataFrame.abs': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.abs.html#pandas.DataFrame.abs',
                        'pandas.DataFrame.add': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.add.html#pandas.DataFrame.add',
                        'pandas.DataFrame.add_prefix': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.add_prefix.html#pandas.DataFrame.add_prefix',
                        'pandas.DataFrame.add_suffix': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.add_suffix.html#pandas.DataFrame.add_suffix',
                        'pandas.DataFrame.agg': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.agg.html#pandas.DataFrame.agg',
                        'pandas.DataFrame.aggregate': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.aggregate.html#pandas.DataFrame.aggregate',
                        'pandas.DataFrame.align': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.align.html#pandas.DataFrame.align',
                        'pandas.DataFrame.all': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.all.html#pandas.DataFrame.all',
                        'pandas.DataFrame.any': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.any.html#pandas.DataFrame.any',
                        'pandas.DataFrame.apply': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.apply.html#pandas.DataFrame.apply',
                        'pandas.DataFrame.applymap': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.applymap.html#pandas.DataFrame.applymap',
                        'pandas.DataFrame.asfreq': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.asfreq.html#pandas.DataFrame.asfreq',
                        'pandas.DataFrame.asof': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.asof.html#pandas.DataFrame.asof',
                        'pandas.DataFrame.assign': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.assign.html#pandas.DataFrame.assign',
                        'pandas.DataFrame.astype': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.astype.html#pandas.DataFrame.astype',
                        'pandas.DataFrame.at_time': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.at_time.html#pandas.DataFrame.at_time',
                        'pandas.DataFrame.backfill': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.backfill.html#pandas.DataFrame.backfill',
                        'pandas.DataFrame.between_time': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.between_time.html#pandas.DataFrame.between_time',
                        'pandas.DataFrame.bfill': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.bfill.html#pandas.DataFrame.bfill',
                        'pandas.DataFrame.bool': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.bool.html#pandas.DataFrame.bool',
                        'pandas.DataFrame.boxplot': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.boxplot.html#pandas.DataFrame.boxplot',
                        'pandas.DataFrame.clip': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.clip.html#pandas.DataFrame.clip',
                        'pandas.DataFrame.combine': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.combine.html#pandas.DataFrame.combine',
                        'pandas.DataFrame.combine_first': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.combine_first.html#pandas.DataFrame.combine_first',
                        'pandas.DataFrame.compare': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.compare.html#pandas.DataFrame.compare',
                        'pandas.DataFrame.convert_dtypes': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.convert_dtypes.html#pandas.DataFrame.convert_dtypes',
                        'pandas.DataFrame.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.copy.html#pandas.DataFrame.copy',
                        'pandas.DataFrame.corr': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.corr.html#pandas.DataFrame.corr',
                        'pandas.DataFrame.corrwith': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.corrwith.html#pandas.DataFrame.corrwith',
                        'pandas.DataFrame.count': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.count.html#pandas.DataFrame.count',
                        'pandas.DataFrame.cov': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.cov.html#pandas.DataFrame.cov',
                        'pandas.DataFrame.cummax': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.cummax.html#pandas.DataFrame.cummax',
                        'pandas.DataFrame.cummin': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.cummin.html#pandas.DataFrame.cummin',
                        'pandas.DataFrame.cumprod': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.cumprod.html#pandas.DataFrame.cumprod',
                        'pandas.DataFrame.cumsum': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.cumsum.html#pandas.DataFrame.cumsum',
                        'pandas.DataFrame.describe': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.describe.html#pandas.DataFrame.describe',
                        'pandas.DataFrame.diff': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.diff.html#pandas.DataFrame.diff',
                        'pandas.DataFrame.div': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.div.html#pandas.DataFrame.div',
                        'pandas.DataFrame.dot': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.dot.html#pandas.DataFrame.dot',
                        'pandas.DataFrame.drop': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.drop.html#pandas.DataFrame.drop',
                        'pandas.DataFrame.drop_duplicates': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.drop_duplicates.html#pandas.DataFrame.drop_duplicates',
                        'pandas.DataFrame.droplevel': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.droplevel.html#pandas.DataFrame.droplevel',
                        'pandas.DataFrame.dropna': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.dropna.html#pandas.DataFrame.dropna',
                        'pandas.DataFrame.duplicated': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.duplicated.html#pandas.DataFrame.duplicated',
                        'pandas.DataFrame.eq': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.eq.html#pandas.DataFrame.eq',
                        'pandas.DataFrame.equals': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.equals.html#pandas.DataFrame.equals',
                        'pandas.DataFrame.eval': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.eval.html#pandas.DataFrame.eval',
                        'pandas.DataFrame.ewm': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.ewm.html#pandas.DataFrame.ewm',
                        'pandas.DataFrame.expanding': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.expanding.html#pandas.DataFrame.expanding',
                        'pandas.DataFrame.explode': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.explode.html#pandas.DataFrame.explode',
                        'pandas.DataFrame.ffill': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.ffill.html#pandas.DataFrame.ffill',
                        'pandas.DataFrame.fillna': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.fillna.html#pandas.DataFrame.fillna',
                        'pandas.DataFrame.filter': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.filter.html#pandas.DataFrame.filter',
                        'pandas.DataFrame.first': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.first.html#pandas.DataFrame.first',
                        'pandas.DataFrame.first_valid_index': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.first_valid_index.html#pandas.DataFrame.first_valid_index',
                        'pandas.DataFrame.floordiv': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.floordiv.html#pandas.DataFrame.floordiv',
                        'pandas.DataFrame.from_dict': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.from_dict.html#pandas.DataFrame.from_dict',
                        'pandas.DataFrame.from_records': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.from_records.html#pandas.DataFrame.from_records',
                        'pandas.DataFrame.ge': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.ge.html#pandas.DataFrame.ge',
                        'pandas.DataFrame.get': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.get.html#pandas.DataFrame.get',
                        'pandas.DataFrame.groupby': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.groupby.html#pandas.DataFrame.groupby',
                        'pandas.DataFrame.gt': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.gt.html#pandas.DataFrame.gt',
                        'pandas.DataFrame.head': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.head.html#pandas.DataFrame.head',
                        'pandas.DataFrame.hist': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.hist.html#pandas.DataFrame.hist',
                        'pandas.DataFrame.idxmax': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.idxmax.html#pandas.DataFrame.idxmax',
                        'pandas.DataFrame.idxmin': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.idxmin.html#pandas.DataFrame.idxmin',
                        'pandas.DataFrame.infer_objects': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.infer_objects.html#pandas.DataFrame.infer_objects',
                        'pandas.DataFrame.info': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.info.html#pandas.DataFrame.info',
                        'pandas.DataFrame.insert': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.insert.html#pandas.DataFrame.insert',
                        'pandas.DataFrame.interpolate': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.interpolate.html#pandas.DataFrame.interpolate',
                        'pandas.DataFrame.isin': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.isin.html#pandas.DataFrame.isin',
                        'pandas.DataFrame.isna': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.isna.html#pandas.DataFrame.isna',
                        'pandas.DataFrame.isnull': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.isnull.html#pandas.DataFrame.isnull',
                        'pandas.DataFrame.items': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.items.html#pandas.DataFrame.items',
                        'pandas.DataFrame.iterrows': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.iterrows.html#pandas.DataFrame.iterrows',
                        'pandas.DataFrame.itertuples': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.itertuples.html#pandas.DataFrame.itertuples',
                        'pandas.DataFrame.join': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.join.html#pandas.DataFrame.join',
                        'pandas.DataFrame.keys': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.keys.html#pandas.DataFrame.keys',
                        'pandas.DataFrame.kurt': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.kurt.html#pandas.DataFrame.kurt',
                        'pandas.DataFrame.kurtosis': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.kurtosis.html#pandas.DataFrame.kurtosis',
                        'pandas.DataFrame.last': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.last.html#pandas.DataFrame.last',
                        'pandas.DataFrame.last_valid_index': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.last_valid_index.html#pandas.DataFrame.last_valid_index',
                        'pandas.DataFrame.le': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.le.html#pandas.DataFrame.le',
                        'pandas.DataFrame.lt': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.lt.html#pandas.DataFrame.lt',
                        'pandas.DataFrame.map': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.map.html#pandas.DataFrame.map',
                        'pandas.DataFrame.mask': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.mask.html#pandas.DataFrame.mask',
                        'pandas.DataFrame.max': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.max.html#pandas.DataFrame.max',
                        'pandas.DataFrame.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.mean.html#pandas.DataFrame.mean',
                        'pandas.DataFrame.median': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.median.html#pandas.DataFrame.median',
                        'pandas.DataFrame.melt': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.melt.html#pandas.DataFrame.melt',
                        'pandas.DataFrame.memory_usage': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.memory_usage.html#pandas.DataFrame.memory_usage',
                        'pandas.DataFrame.merge': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.merge.html#pandas.DataFrame.merge',
                        'pandas.DataFrame.min': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.min.html#pandas.DataFrame.min',
                        'pandas.DataFrame.mod': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.mod.html#pandas.DataFrame.mod',
                        'pandas.DataFrame.mode': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.mode.html#pandas.DataFrame.mode',
                        'pandas.DataFrame.mul': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.mul.html#pandas.DataFrame.mul',
                        'pandas.DataFrame.ne': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.ne.html#pandas.DataFrame.ne',
                        'pandas.DataFrame.nlargest': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.nlargest.html#pandas.DataFrame.nlargest',
                        'pandas.DataFrame.notna': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.notna.html#pandas.DataFrame.notna',
                        'pandas.DataFrame.notnull': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.notnull.html#pandas.DataFrame.notnull',
                        'pandas.DataFrame.nsmallest': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.nsmallest.html#pandas.DataFrame.nsmallest',
                        'pandas.DataFrame.nunique': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.nunique.html#pandas.DataFrame.nunique',
                        'pandas.DataFrame.pad': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.pad.html#pandas.DataFrame.pad',
                        'pandas.DataFrame.pct_change': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.pct_change.html#pandas.DataFrame.pct_change',
                        'pandas.DataFrame.pipe': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.pipe.html#pandas.DataFrame.pipe',
                        'pandas.DataFrame.pivot': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.pivot.html#pandas.DataFrame.pivot',
                        'pandas.DataFrame.pivot_table': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.pivot_table.html#pandas.DataFrame.pivot_table',
                        'pandas.DataFrame.plot': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.html#pandas.DataFrame.plot',
                        'pandas.DataFrame.pop': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.pop.html#pandas.DataFrame.pop',
                        'pandas.DataFrame.pow': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.pow.html#pandas.DataFrame.pow',
                        'pandas.DataFrame.prod': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.prod.html#pandas.DataFrame.prod',
                        'pandas.DataFrame.product': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.product.html#pandas.DataFrame.product',
                        'pandas.DataFrame.quantile': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.quantile.html#pandas.DataFrame.quantile',
                        'pandas.DataFrame.query': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.query.html#pandas.DataFrame.query',
                        'pandas.DataFrame.radd': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.radd.html#pandas.DataFrame.radd',
                        'pandas.DataFrame.rank': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rank.html#pandas.DataFrame.rank',
                        'pandas.DataFrame.rdiv': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rdiv.html#pandas.DataFrame.rdiv',
                        'pandas.DataFrame.reindex': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.reindex.html#pandas.DataFrame.reindex',
                        'pandas.DataFrame.reindex_like': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.reindex_like.html#pandas.DataFrame.reindex_like',
                        'pandas.DataFrame.rename': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rename.html#pandas.DataFrame.rename',
                        'pandas.DataFrame.rename_axis': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rename_axis.html#pandas.DataFrame.rename_axis',
                        'pandas.DataFrame.reorder_levels': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.reorder_levels.html#pandas.DataFrame.reorder_levels',
                        'pandas.DataFrame.replace': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.replace.html#pandas.DataFrame.replace',
                        'pandas.DataFrame.resample': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.resample.html#pandas.DataFrame.resample',
                        'pandas.DataFrame.reset_index': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.reset_index.html#pandas.DataFrame.reset_index',
                        'pandas.DataFrame.rfloordiv': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rfloordiv.html#pandas.DataFrame.rfloordiv',
                        'pandas.DataFrame.rmod': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rmod.html#pandas.DataFrame.rmod',
                        'pandas.DataFrame.rmul': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rmul.html#pandas.DataFrame.rmul',
                        'pandas.DataFrame.rolling': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rolling.html#pandas.DataFrame.rolling',
                        'pandas.DataFrame.round': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.round.html#pandas.DataFrame.round',
                        'pandas.DataFrame.rpow': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rpow.html#pandas.DataFrame.rpow',
                        'pandas.DataFrame.rsub': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rsub.html#pandas.DataFrame.rsub',
                        'pandas.DataFrame.rtruediv': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.rtruediv.html#pandas.DataFrame.rtruediv',
                        'pandas.DataFrame.sample': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sample.html#pandas.DataFrame.sample',
                        'pandas.DataFrame.select_dtypes': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.select_dtypes.html#pandas.DataFrame.select_dtypes',
                        'pandas.DataFrame.sem': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sem.html#pandas.DataFrame.sem',
                        'pandas.DataFrame.set_axis': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.set_axis.html#pandas.DataFrame.set_axis',
                        'pandas.DataFrame.set_flags': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.set_flags.html#pandas.DataFrame.set_flags',
                        'pandas.DataFrame.set_index': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.set_index.html#pandas.DataFrame.set_index',
                        'pandas.DataFrame.shift': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.shift.html#pandas.DataFrame.shift',
                        'pandas.DataFrame.skew': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.skew.html#pandas.DataFrame.skew',
                        'pandas.DataFrame.sort_index': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sort_index.html#pandas.DataFrame.sort_index',
                        'pandas.DataFrame.sort_values': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sort_values.html#pandas.DataFrame.sort_values',
                        'pandas.DataFrame.sparse': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sparse.html#pandas.DataFrame.sparse',
                        'pandas.DataFrame.squeeze': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.squeeze.html#pandas.DataFrame.squeeze',
                        'pandas.DataFrame.stack': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.stack.html#pandas.DataFrame.stack',
                        'pandas.DataFrame.std': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.std.html#pandas.DataFrame.std',
                        'pandas.DataFrame.sub': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sub.html#pandas.DataFrame.sub',
                        'pandas.DataFrame.sum': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sum.html#pandas.DataFrame.sum',
                        'pandas.DataFrame.swapaxes': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.swapaxes.html#pandas.DataFrame.swapaxes',
                        'pandas.DataFrame.swaplevel': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.swaplevel.html#pandas.DataFrame.swaplevel',
                        'pandas.DataFrame.tail': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.tail.html#pandas.DataFrame.tail',
                        'pandas.DataFrame.take': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.take.html#pandas.DataFrame.take',
                        'pandas.DataFrame.to_clipboard': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_clipboard.html#pandas.DataFrame.to_clipboard',
                        'pandas.DataFrame.to_csv': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_csv.html#pandas.DataFrame.to_csv',
                        'pandas.DataFrame.to_dict': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_dict.html#pandas.DataFrame.to_dict',
                        'pandas.DataFrame.to_excel': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_excel.html#pandas.DataFrame.to_excel',
                        'pandas.DataFrame.to_feather': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_feather.html#pandas.DataFrame.to_feather',
                        'pandas.DataFrame.to_gbq': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_gbq.html#pandas.DataFrame.to_gbq',
                        'pandas.DataFrame.to_hdf': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_hdf.html#pandas.DataFrame.to_hdf',
                        'pandas.DataFrame.to_html': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_html.html#pandas.DataFrame.to_html',
                        'pandas.DataFrame.to_json': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_json.html#pandas.DataFrame.to_json',
                        'pandas.DataFrame.to_latex': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_latex.html#pandas.DataFrame.to_latex',
                        'pandas.DataFrame.to_markdown': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_markdown.html#pandas.DataFrame.to_markdown',
                        'pandas.DataFrame.to_numpy': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_numpy.html#pandas.DataFrame.to_numpy',
                        'pandas.DataFrame.to_orc': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_orc.html#pandas.DataFrame.to_orc',
                        'pandas.DataFrame.to_parquet': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_parquet.html#pandas.DataFrame.to_parquet',
                        'pandas.DataFrame.to_period': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_period.html#pandas.DataFrame.to_period',
                        'pandas.DataFrame.to_pickle': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_pickle.html#pandas.DataFrame.to_pickle',
                        'pandas.DataFrame.to_records': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_records.html#pandas.DataFrame.to_records',
                        'pandas.DataFrame.to_sql': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_sql.html#pandas.DataFrame.to_sql',
                        'pandas.DataFrame.to_stata': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_stata.html#pandas.DataFrame.to_stata',
                        'pandas.DataFrame.to_string': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_string.html#pandas.DataFrame.to_string',
                        'pandas.DataFrame.to_timestamp': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_timestamp.html#pandas.DataFrame.to_timestamp',
                        'pandas.DataFrame.to_xarray': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_xarray.html#pandas.DataFrame.to_xarray',
                        'pandas.DataFrame.to_xml': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_xml.html#pandas.DataFrame.to_xml',
                        'pandas.DataFrame.transform': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.transform.html#pandas.DataFrame.transform',
                        'pandas.DataFrame.transpose': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.transpose.html#pandas.DataFrame.transpose',
                        'pandas.DataFrame.truediv': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.truediv.html#pandas.DataFrame.truediv',
                        'pandas.DataFrame.truncate': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.truncate.html#pandas.DataFrame.truncate',
                        'pandas.DataFrame.tz_convert': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.tz_convert.html#pandas.DataFrame.tz_convert',
                        'pandas.DataFrame.tz_localize': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.tz_localize.html#pandas.DataFrame.tz_localize',
                        'pandas.DataFrame.unstack': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.unstack.html#pandas.DataFrame.unstack',
                        'pandas.DataFrame.update': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.update.html#pandas.DataFrame.update',
                        'pandas.DataFrame.value_counts': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.value_counts.html#pandas.DataFrame.value_counts',
                        'pandas.DataFrame.var': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.var.html#pandas.DataFrame.var',
                        'pandas.DataFrame.where': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.where.html#pandas.DataFrame.where',
                        'pandas.DataFrame.xs': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.xs.html#pandas.DataFrame.xs',
                        'pandas.DatetimeIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.html#pandas.DatetimeIndex',
                        'pandas.DatetimeIndex.as_unit': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.as_unit.html#pandas.DatetimeIndex.as_unit',
                        'pandas.DatetimeIndex.ceil': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.ceil.html#pandas.DatetimeIndex.ceil',
                        'pandas.DatetimeIndex.day_name': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.day_name.html#pandas.DatetimeIndex.day_name',
                        'pandas.DatetimeIndex.floor': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.floor.html#pandas.DatetimeIndex.floor',
                        'pandas.DatetimeIndex.indexer_at_time': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.indexer_at_time.html#pandas.DatetimeIndex.indexer_at_time',
                        'pandas.DatetimeIndex.indexer_between_time': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.indexer_between_time.html#pandas.DatetimeIndex.indexer_between_time',
                        'pandas.DatetimeIndex.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.mean.html#pandas.DatetimeIndex.mean',
                        'pandas.DatetimeIndex.month_name': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.month_name.html#pandas.DatetimeIndex.month_name',
                        'pandas.DatetimeIndex.normalize': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.normalize.html#pandas.DatetimeIndex.normalize',
                        'pandas.DatetimeIndex.round': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.round.html#pandas.DatetimeIndex.round',
                        'pandas.DatetimeIndex.snap': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.snap.html#pandas.DatetimeIndex.snap',
                        'pandas.DatetimeIndex.std': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.std.html#pandas.DatetimeIndex.std',
                        'pandas.DatetimeIndex.strftime': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.strftime.html#pandas.DatetimeIndex.strftime',
                        'pandas.DatetimeIndex.to_frame': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.to_frame.html#pandas.DatetimeIndex.to_frame',
                        'pandas.DatetimeIndex.to_period': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.to_period.html#pandas.DatetimeIndex.to_period',
                        'pandas.DatetimeIndex.to_pydatetime': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.to_pydatetime.html#pandas.DatetimeIndex.to_pydatetime',
                        'pandas.DatetimeIndex.to_series': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.to_series.html#pandas.DatetimeIndex.to_series',
                        'pandas.DatetimeIndex.tz_convert': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.tz_convert.html#pandas.DatetimeIndex.tz_convert',
                        'pandas.DatetimeIndex.tz_localize': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.tz_localize.html#pandas.DatetimeIndex.tz_localize',
                        'pandas.DatetimeTZDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeTZDtype.html#pandas.DatetimeTZDtype',
                        'pandas.ExcelFile': 'https://pandas.pydata.org/docs/reference/api/pandas.ExcelFile.html#pandas.ExcelFile',
                        'pandas.ExcelFile.parse': 'https://pandas.pydata.org/docs/reference/api/pandas.ExcelFile.parse.html#pandas.ExcelFile.parse',
                        'pandas.ExcelWriter': 'https://pandas.pydata.org/docs/reference/api/pandas.ExcelWriter.html#pandas.ExcelWriter',
                        'pandas.Flags': 'https://pandas.pydata.org/docs/reference/api/pandas.Flags.html#pandas.Flags',
                        'pandas.Float32Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Float32Dtype.html#pandas.Float32Dtype',
                        'pandas.Float64Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Float64Dtype.html#pandas.Float64Dtype',
                        'pandas.Grouper': 'https://pandas.pydata.org/docs/reference/api/pandas.Grouper.html#pandas.Grouper',
                        'pandas.HDFStore.append': 'https://pandas.pydata.org/docs/reference/api/pandas.HDFStore.append.html#pandas.HDFStore.append',
                        'pandas.HDFStore.get': 'https://pandas.pydata.org/docs/reference/api/pandas.HDFStore.get.html#pandas.HDFStore.get',
                        'pandas.HDFStore.groups': 'https://pandas.pydata.org/docs/reference/api/pandas.HDFStore.groups.html#pandas.HDFStore.groups',
                        'pandas.HDFStore.info': 'https://pandas.pydata.org/docs/reference/api/pandas.HDFStore.info.html#pandas.HDFStore.info',
                        'pandas.HDFStore.keys': 'https://pandas.pydata.org/docs/reference/api/pandas.HDFStore.keys.html#pandas.HDFStore.keys',
                        'pandas.HDFStore.put': 'https://pandas.pydata.org/docs/reference/api/pandas.HDFStore.put.html#pandas.HDFStore.put',
                        'pandas.HDFStore.select': 'https://pandas.pydata.org/docs/reference/api/pandas.HDFStore.select.html#pandas.HDFStore.select',
                        'pandas.HDFStore.walk': 'https://pandas.pydata.org/docs/reference/api/pandas.HDFStore.walk.html#pandas.HDFStore.walk',
                        'pandas.Index': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.html#pandas.Index',
                        'pandas.Index.all': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.all.html#pandas.Index.all',
                        'pandas.Index.any': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.any.html#pandas.Index.any',
                        'pandas.Index.append': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.append.html#pandas.Index.append',
                        'pandas.Index.argmax': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.argmax.html#pandas.Index.argmax',
                        'pandas.Index.argmin': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.argmin.html#pandas.Index.argmin',
                        'pandas.Index.argsort': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.argsort.html#pandas.Index.argsort',
                        'pandas.Index.asof': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.asof.html#pandas.Index.asof',
                        'pandas.Index.asof_locs': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.asof_locs.html#pandas.Index.asof_locs',
                        'pandas.Index.astype': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.astype.html#pandas.Index.astype',
                        'pandas.Index.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.copy.html#pandas.Index.copy',
                        'pandas.Index.delete': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.delete.html#pandas.Index.delete',
                        'pandas.Index.difference': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.difference.html#pandas.Index.difference',
                        'pandas.Index.drop': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.drop.html#pandas.Index.drop',
                        'pandas.Index.drop_duplicates': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.drop_duplicates.html#pandas.Index.drop_duplicates',
                        'pandas.Index.droplevel': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.droplevel.html#pandas.Index.droplevel',
                        'pandas.Index.dropna': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.dropna.html#pandas.Index.dropna',
                        'pandas.Index.duplicated': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.duplicated.html#pandas.Index.duplicated',
                        'pandas.Index.equals': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.equals.html#pandas.Index.equals',
                        'pandas.Index.factorize': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.factorize.html#pandas.Index.factorize',
                        'pandas.Index.fillna': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.fillna.html#pandas.Index.fillna',
                        'pandas.Index.get_indexer': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.get_indexer.html#pandas.Index.get_indexer',
                        'pandas.Index.get_indexer_for': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.get_indexer_for.html#pandas.Index.get_indexer_for',
                        'pandas.Index.get_indexer_non_unique': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.get_indexer_non_unique.html#pandas.Index.get_indexer_non_unique',
                        'pandas.Index.get_level_values': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.get_level_values.html#pandas.Index.get_level_values',
                        'pandas.Index.get_loc': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.get_loc.html#pandas.Index.get_loc',
                        'pandas.Index.get_slice_bound': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.get_slice_bound.html#pandas.Index.get_slice_bound',
                        'pandas.Index.identical': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.identical.html#pandas.Index.identical',
                        'pandas.Index.insert': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.insert.html#pandas.Index.insert',
                        'pandas.Index.intersection': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.intersection.html#pandas.Index.intersection',
                        'pandas.Index.is_': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.is_.html#pandas.Index.is_',
                        'pandas.Index.is_boolean': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.is_boolean.html#pandas.Index.is_boolean',
                        'pandas.Index.is_categorical': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.is_categorical.html#pandas.Index.is_categorical',
                        'pandas.Index.is_floating': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.is_floating.html#pandas.Index.is_floating',
                        'pandas.Index.is_integer': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.is_integer.html#pandas.Index.is_integer',
                        'pandas.Index.is_interval': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.is_interval.html#pandas.Index.is_interval',
                        'pandas.Index.is_numeric': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.is_numeric.html#pandas.Index.is_numeric',
                        'pandas.Index.is_object': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.is_object.html#pandas.Index.is_object',
                        'pandas.Index.isin': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.isin.html#pandas.Index.isin',
                        'pandas.Index.isna': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.isna.html#pandas.Index.isna',
                        'pandas.Index.item': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.item.html#pandas.Index.item',
                        'pandas.Index.join': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.join.html#pandas.Index.join',
                        'pandas.Index.map': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.map.html#pandas.Index.map',
                        'pandas.Index.max': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.max.html#pandas.Index.max',
                        'pandas.Index.memory_usage': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.memory_usage.html#pandas.Index.memory_usage',
                        'pandas.Index.min': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.min.html#pandas.Index.min',
                        'pandas.Index.notna': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.notna.html#pandas.Index.notna',
                        'pandas.Index.nunique': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.nunique.html#pandas.Index.nunique',
                        'pandas.Index.putmask': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.putmask.html#pandas.Index.putmask',
                        'pandas.Index.ravel': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.ravel.html#pandas.Index.ravel',
                        'pandas.Index.reindex': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.reindex.html#pandas.Index.reindex',
                        'pandas.Index.rename': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.rename.html#pandas.Index.rename',
                        'pandas.Index.repeat': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.repeat.html#pandas.Index.repeat',
                        'pandas.Index.searchsorted': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.searchsorted.html#pandas.Index.searchsorted',
                        'pandas.Index.set_names': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.set_names.html#pandas.Index.set_names',
                        'pandas.Index.shift': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.shift.html#pandas.Index.shift',
                        'pandas.Index.slice_indexer': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.slice_indexer.html#pandas.Index.slice_indexer',
                        'pandas.Index.slice_locs': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.slice_locs.html#pandas.Index.slice_locs',
                        'pandas.Index.sort_values': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.sort_values.html#pandas.Index.sort_values',
                        'pandas.Index.str': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.str.html#pandas.Index.str',
                        'pandas.Index.symmetric_difference': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.symmetric_difference.html#pandas.Index.symmetric_difference',
                        'pandas.Index.take': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.take.html#pandas.Index.take',
                        'pandas.Index.to_frame': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.to_frame.html#pandas.Index.to_frame',
                        'pandas.Index.to_list': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.to_list.html#pandas.Index.to_list',
                        'pandas.Index.to_series': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.to_series.html#pandas.Index.to_series',
                        'pandas.Index.union': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.union.html#pandas.Index.union',
                        'pandas.Index.unique': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.unique.html#pandas.Index.unique',
                        'pandas.Index.value_counts': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.value_counts.html#pandas.Index.value_counts',
                        'pandas.Index.view': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.view.html#pandas.Index.view',
                        'pandas.Index.where': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.where.html#pandas.Index.where',
                        'pandas.Int16Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Int16Dtype.html#pandas.Int16Dtype',
                        'pandas.Int32Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Int32Dtype.html#pandas.Int32Dtype',
                        'pandas.Int64Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Int64Dtype.html#pandas.Int64Dtype',
                        'pandas.Int8Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Int8Dtype.html#pandas.Int8Dtype',
                        'pandas.Interval': 'https://pandas.pydata.org/docs/reference/api/pandas.Interval.html#pandas.Interval',
                        'pandas.Interval.overlaps': 'https://pandas.pydata.org/docs/reference/api/pandas.Interval.overlaps.html#pandas.Interval.overlaps',
                        'pandas.IntervalDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalDtype.html#pandas.IntervalDtype',
                        'pandas.IntervalIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.html#pandas.IntervalIndex',
                        'pandas.IntervalIndex.contains': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.contains.html#pandas.IntervalIndex.contains',
                        'pandas.IntervalIndex.from_arrays': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.from_arrays.html#pandas.IntervalIndex.from_arrays',
                        'pandas.IntervalIndex.from_breaks': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.from_breaks.html#pandas.IntervalIndex.from_breaks',
                        'pandas.IntervalIndex.from_tuples': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.from_tuples.html#pandas.IntervalIndex.from_tuples',
                        'pandas.IntervalIndex.get_indexer': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.get_indexer.html#pandas.IntervalIndex.get_indexer',
                        'pandas.IntervalIndex.get_loc': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.get_loc.html#pandas.IntervalIndex.get_loc',
                        'pandas.IntervalIndex.overlaps': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.overlaps.html#pandas.IntervalIndex.overlaps',
                        'pandas.IntervalIndex.set_closed': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.set_closed.html#pandas.IntervalIndex.set_closed',
                        'pandas.IntervalIndex.to_tuples': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.to_tuples.html#pandas.IntervalIndex.to_tuples',
                        'pandas.MultiIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.html#pandas.MultiIndex',
                        'pandas.MultiIndex.append': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.append.html#pandas.MultiIndex.append',
                        'pandas.MultiIndex.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.copy.html#pandas.MultiIndex.copy',
                        'pandas.MultiIndex.drop': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.drop.html#pandas.MultiIndex.drop',
                        'pandas.MultiIndex.droplevel': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.droplevel.html#pandas.MultiIndex.droplevel',
                        'pandas.MultiIndex.from_arrays': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.from_arrays.html#pandas.MultiIndex.from_arrays',
                        'pandas.MultiIndex.from_frame': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.from_frame.html#pandas.MultiIndex.from_frame',
                        'pandas.MultiIndex.from_product': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.from_product.html#pandas.MultiIndex.from_product',
                        'pandas.MultiIndex.from_tuples': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.from_tuples.html#pandas.MultiIndex.from_tuples',
                        'pandas.MultiIndex.get_indexer': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.get_indexer.html#pandas.MultiIndex.get_indexer',
                        'pandas.MultiIndex.get_level_values': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.get_level_values.html#pandas.MultiIndex.get_level_values',
                        'pandas.MultiIndex.get_loc': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.get_loc.html#pandas.MultiIndex.get_loc',
                        'pandas.MultiIndex.get_loc_level': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.get_loc_level.html#pandas.MultiIndex.get_loc_level',
                        'pandas.MultiIndex.get_locs': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.get_locs.html#pandas.MultiIndex.get_locs',
                        'pandas.MultiIndex.remove_unused_levels': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.remove_unused_levels.html#pandas.MultiIndex.remove_unused_levels',
                        'pandas.MultiIndex.reorder_levels': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.reorder_levels.html#pandas.MultiIndex.reorder_levels',
                        'pandas.MultiIndex.set_codes': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.set_codes.html#pandas.MultiIndex.set_codes',
                        'pandas.MultiIndex.set_levels': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.set_levels.html#pandas.MultiIndex.set_levels',
                        'pandas.MultiIndex.sortlevel': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.sortlevel.html#pandas.MultiIndex.sortlevel',
                        'pandas.MultiIndex.swaplevel': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.swaplevel.html#pandas.MultiIndex.swaplevel',
                        'pandas.MultiIndex.to_flat_index': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.to_flat_index.html#pandas.MultiIndex.to_flat_index',
                        'pandas.MultiIndex.to_frame': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.to_frame.html#pandas.MultiIndex.to_frame',
                        'pandas.MultiIndex.truncate': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.truncate.html#pandas.MultiIndex.truncate',
                        'pandas.NamedAgg': 'https://pandas.pydata.org/docs/reference/api/pandas.NamedAgg.html#pandas.NamedAgg',
                        'pandas.Period': 'https://pandas.pydata.org/docs/reference/api/pandas.Period.html#pandas.Period',
                        'pandas.Period.asfreq': 'https://pandas.pydata.org/docs/reference/api/pandas.Period.asfreq.html#pandas.Period.asfreq',
                        'pandas.Period.now': 'https://pandas.pydata.org/docs/reference/api/pandas.Period.now.html#pandas.Period.now',
                        'pandas.Period.strftime': 'https://pandas.pydata.org/docs/reference/api/pandas.Period.strftime.html#pandas.Period.strftime',
                        'pandas.Period.to_timestamp': 'https://pandas.pydata.org/docs/reference/api/pandas.Period.to_timestamp.html#pandas.Period.to_timestamp',
                        'pandas.PeriodDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.PeriodDtype.html#pandas.PeriodDtype',
                        'pandas.PeriodIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.PeriodIndex.html#pandas.PeriodIndex',
                        'pandas.PeriodIndex.asfreq': 'https://pandas.pydata.org/docs/reference/api/pandas.PeriodIndex.asfreq.html#pandas.PeriodIndex.asfreq',
                        'pandas.PeriodIndex.from_fields': 'https://pandas.pydata.org/docs/reference/api/pandas.PeriodIndex.from_fields.html#pandas.PeriodIndex.from_fields',
                        'pandas.PeriodIndex.from_ordinals': 'https://pandas.pydata.org/docs/reference/api/pandas.PeriodIndex.from_ordinals.html#pandas.PeriodIndex.from_ordinals',
                        'pandas.PeriodIndex.strftime': 'https://pandas.pydata.org/docs/reference/api/pandas.PeriodIndex.strftime.html#pandas.PeriodIndex.strftime',
                        'pandas.PeriodIndex.to_timestamp': 'https://pandas.pydata.org/docs/reference/api/pandas.PeriodIndex.to_timestamp.html#pandas.PeriodIndex.to_timestamp',
                        'pandas.RangeIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.RangeIndex.html#pandas.RangeIndex',
                        'pandas.RangeIndex.from_range': 'https://pandas.pydata.org/docs/reference/api/pandas.RangeIndex.from_range.html#pandas.RangeIndex.from_range',
                        'pandas.Series': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.html#pandas.Series',
                        'pandas.Series.__array__': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.__array__.html#pandas.Series.__array__',
                        'pandas.Series.__iter__': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.__iter__.html#pandas.Series.__iter__',
                        'pandas.Series.abs': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.abs.html#pandas.Series.abs',
                        'pandas.Series.add': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.add.html#pandas.Series.add',
                        'pandas.Series.add_prefix': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.add_prefix.html#pandas.Series.add_prefix',
                        'pandas.Series.add_suffix': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.add_suffix.html#pandas.Series.add_suffix',
                        'pandas.Series.agg': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.agg.html#pandas.Series.agg',
                        'pandas.Series.aggregate': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.aggregate.html#pandas.Series.aggregate',
                        'pandas.Series.align': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.align.html#pandas.Series.align',
                        'pandas.Series.all': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.all.html#pandas.Series.all',
                        'pandas.Series.any': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.any.html#pandas.Series.any',
                        'pandas.Series.apply': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.apply.html#pandas.Series.apply',
                        'pandas.Series.argmax': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.argmax.html#pandas.Series.argmax',
                        'pandas.Series.argmin': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.argmin.html#pandas.Series.argmin',
                        'pandas.Series.argsort': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.argsort.html#pandas.Series.argsort',
                        'pandas.Series.asfreq': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.asfreq.html#pandas.Series.asfreq',
                        'pandas.Series.asof': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.asof.html#pandas.Series.asof',
                        'pandas.Series.astype': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.astype.html#pandas.Series.astype',
                        'pandas.Series.at_time': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.at_time.html#pandas.Series.at_time',
                        'pandas.Series.autocorr': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.autocorr.html#pandas.Series.autocorr',
                        'pandas.Series.backfill': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.backfill.html#pandas.Series.backfill',
                        'pandas.Series.between': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.between.html#pandas.Series.between',
                        'pandas.Series.between_time': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.between_time.html#pandas.Series.between_time',
                        'pandas.Series.bfill': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.bfill.html#pandas.Series.bfill',
                        'pandas.Series.bool': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.bool.html#pandas.Series.bool',
                        'pandas.Series.case_when': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.case_when.html#pandas.Series.case_when',
                        'pandas.Series.cat': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cat.html#pandas.Series.cat',
                        'pandas.Series.clip': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.clip.html#pandas.Series.clip',
                        'pandas.Series.combine': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.combine.html#pandas.Series.combine',
                        'pandas.Series.combine_first': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.combine_first.html#pandas.Series.combine_first',
                        'pandas.Series.compare': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.compare.html#pandas.Series.compare',
                        'pandas.Series.convert_dtypes': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.convert_dtypes.html#pandas.Series.convert_dtypes',
                        'pandas.Series.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.copy.html#pandas.Series.copy',
                        'pandas.Series.corr': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.corr.html#pandas.Series.corr',
                        'pandas.Series.count': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.count.html#pandas.Series.count',
                        'pandas.Series.cov': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cov.html#pandas.Series.cov',
                        'pandas.Series.cummax': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cummax.html#pandas.Series.cummax',
                        'pandas.Series.cummin': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cummin.html#pandas.Series.cummin',
                        'pandas.Series.cumprod': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cumprod.html#pandas.Series.cumprod',
                        'pandas.Series.cumsum': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cumsum.html#pandas.Series.cumsum',
                        'pandas.Series.describe': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.describe.html#pandas.Series.describe',
                        'pandas.Series.diff': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.diff.html#pandas.Series.diff',
                        'pandas.Series.div': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.div.html#pandas.Series.div',
                        'pandas.Series.dot': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dot.html#pandas.Series.dot',
                        'pandas.Series.drop': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.drop.html#pandas.Series.drop',
                        'pandas.Series.drop_duplicates': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.drop_duplicates.html#pandas.Series.drop_duplicates',
                        'pandas.Series.droplevel': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.droplevel.html#pandas.Series.droplevel',
                        'pandas.Series.dropna': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dropna.html#pandas.Series.dropna',
                        'pandas.Series.dt': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.html#pandas.Series.dt',
                        'pandas.Series.duplicated': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.duplicated.html#pandas.Series.duplicated',
                        'pandas.Series.eq': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.eq.html#pandas.Series.eq',
                        'pandas.Series.equals': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.equals.html#pandas.Series.equals',
                        'pandas.Series.ewm': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.ewm.html#pandas.Series.ewm',
                        'pandas.Series.expanding': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.expanding.html#pandas.Series.expanding',
                        'pandas.Series.explode': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.explode.html#pandas.Series.explode',
                        'pandas.Series.factorize': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.factorize.html#pandas.Series.factorize',
                        'pandas.Series.ffill': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.ffill.html#pandas.Series.ffill',
                        'pandas.Series.fillna': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.fillna.html#pandas.Series.fillna',
                        'pandas.Series.filter': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.filter.html#pandas.Series.filter',
                        'pandas.Series.first': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.first.html#pandas.Series.first',
                        'pandas.Series.first_valid_index': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.first_valid_index.html#pandas.Series.first_valid_index',
                        'pandas.Series.floordiv': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.floordiv.html#pandas.Series.floordiv',
                        'pandas.Series.ge': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.ge.html#pandas.Series.ge',
                        'pandas.Series.get': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.get.html#pandas.Series.get',
                        'pandas.Series.groupby': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.groupby.html#pandas.Series.groupby',
                        'pandas.Series.gt': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.gt.html#pandas.Series.gt',
                        'pandas.Series.head': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.head.html#pandas.Series.head',
                        'pandas.Series.hist': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.hist.html#pandas.Series.hist',
                        'pandas.Series.idxmax': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.idxmax.html#pandas.Series.idxmax',
                        'pandas.Series.idxmin': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.idxmin.html#pandas.Series.idxmin',
                        'pandas.Series.infer_objects': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.infer_objects.html#pandas.Series.infer_objects',
                        'pandas.Series.interpolate': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.interpolate.html#pandas.Series.interpolate',
                        'pandas.Series.isin': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.isin.html#pandas.Series.isin',
                        'pandas.Series.isna': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.isna.html#pandas.Series.isna',
                        'pandas.Series.isnull': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.isnull.html#pandas.Series.isnull',
                        'pandas.Series.item': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.item.html#pandas.Series.item',
                        'pandas.Series.items': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.items.html#pandas.Series.items',
                        'pandas.Series.keys': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.keys.html#pandas.Series.keys',
                        'pandas.Series.kurt': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.kurt.html#pandas.Series.kurt',
                        'pandas.Series.kurtosis': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.kurtosis.html#pandas.Series.kurtosis',
                        'pandas.Series.last': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.last.html#pandas.Series.last',
                        'pandas.Series.last_valid_index': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.last_valid_index.html#pandas.Series.last_valid_index',
                        'pandas.Series.le': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.le.html#pandas.Series.le',
                        'pandas.Series.lt': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.lt.html#pandas.Series.lt',
                        'pandas.Series.map': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.map.html#pandas.Series.map',
                        'pandas.Series.mask': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.mask.html#pandas.Series.mask',
                        'pandas.Series.max': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.max.html#pandas.Series.max',
                        'pandas.Series.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.mean.html#pandas.Series.mean',
                        'pandas.Series.median': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.median.html#pandas.Series.median',
                        'pandas.Series.memory_usage': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.memory_usage.html#pandas.Series.memory_usage',
                        'pandas.Series.min': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.min.html#pandas.Series.min',
                        'pandas.Series.mod': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.mod.html#pandas.Series.mod',
                        'pandas.Series.mode': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.mode.html#pandas.Series.mode',
                        'pandas.Series.mul': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.mul.html#pandas.Series.mul',
                        'pandas.Series.ne': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.ne.html#pandas.Series.ne',
                        'pandas.Series.nlargest': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.nlargest.html#pandas.Series.nlargest',
                        'pandas.Series.notna': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.notna.html#pandas.Series.notna',
                        'pandas.Series.notnull': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.notnull.html#pandas.Series.notnull',
                        'pandas.Series.nsmallest': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.nsmallest.html#pandas.Series.nsmallest',
                        'pandas.Series.nunique': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.nunique.html#pandas.Series.nunique',
                        'pandas.Series.pad': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.pad.html#pandas.Series.pad',
                        'pandas.Series.pct_change': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.pct_change.html#pandas.Series.pct_change',
                        'pandas.Series.pipe': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.pipe.html#pandas.Series.pipe',
                        'pandas.Series.plot': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.html#pandas.Series.plot',
                        'pandas.Series.pop': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.pop.html#pandas.Series.pop',
                        'pandas.Series.pow': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.pow.html#pandas.Series.pow',
                        'pandas.Series.prod': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.prod.html#pandas.Series.prod',
                        'pandas.Series.product': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.product.html#pandas.Series.product',
                        'pandas.Series.quantile': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.quantile.html#pandas.Series.quantile',
                        'pandas.Series.radd': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.radd.html#pandas.Series.radd',
                        'pandas.Series.rank': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rank.html#pandas.Series.rank',
                        'pandas.Series.ravel': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.ravel.html#pandas.Series.ravel',
                        'pandas.Series.rdiv': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rdiv.html#pandas.Series.rdiv',
                        'pandas.Series.reindex': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.reindex.html#pandas.Series.reindex',
                        'pandas.Series.reindex_like': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.reindex_like.html#pandas.Series.reindex_like',
                        'pandas.Series.rename': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rename.html#pandas.Series.rename',
                        'pandas.Series.rename_axis': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rename_axis.html#pandas.Series.rename_axis',
                        'pandas.Series.reorder_levels': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.reorder_levels.html#pandas.Series.reorder_levels',
                        'pandas.Series.repeat': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.repeat.html#pandas.Series.repeat',
                        'pandas.Series.replace': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.replace.html#pandas.Series.replace',
                        'pandas.Series.resample': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.resample.html#pandas.Series.resample',
                        'pandas.Series.reset_index': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.reset_index.html#pandas.Series.reset_index',
                        'pandas.Series.rfloordiv': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rfloordiv.html#pandas.Series.rfloordiv',
                        'pandas.Series.rmod': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rmod.html#pandas.Series.rmod',
                        'pandas.Series.rmul': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rmul.html#pandas.Series.rmul',
                        'pandas.Series.rolling': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rolling.html#pandas.Series.rolling',
                        'pandas.Series.round': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.round.html#pandas.Series.round',
                        'pandas.Series.rpow': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rpow.html#pandas.Series.rpow',
                        'pandas.Series.rsub': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rsub.html#pandas.Series.rsub',
                        'pandas.Series.rtruediv': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.rtruediv.html#pandas.Series.rtruediv',
                        'pandas.Series.sample': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.sample.html#pandas.Series.sample',
                        'pandas.Series.searchsorted': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.searchsorted.html#pandas.Series.searchsorted',
                        'pandas.Series.sem': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.sem.html#pandas.Series.sem',
                        'pandas.Series.set_axis': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.set_axis.html#pandas.Series.set_axis',
                        'pandas.Series.set_flags': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.set_flags.html#pandas.Series.set_flags',
                        'pandas.Series.shift': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.shift.html#pandas.Series.shift',
                        'pandas.Series.skew': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.skew.html#pandas.Series.skew',
                        'pandas.Series.sort_index': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.sort_index.html#pandas.Series.sort_index',
                        'pandas.Series.sort_values': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.sort_values.html#pandas.Series.sort_values',
                        'pandas.Series.sparse': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.sparse.html#pandas.Series.sparse',
                        'pandas.Series.squeeze': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.squeeze.html#pandas.Series.squeeze',
                        'pandas.Series.std': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.std.html#pandas.Series.std',
                        'pandas.Series.str': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.html#pandas.Series.str',
                        'pandas.Series.sub': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.sub.html#pandas.Series.sub',
                        'pandas.Series.sum': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.sum.html#pandas.Series.sum',
                        'pandas.Series.swaplevel': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.swaplevel.html#pandas.Series.swaplevel',
                        'pandas.Series.tail': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.tail.html#pandas.Series.tail',
                        'pandas.Series.take': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.take.html#pandas.Series.take',
                        'pandas.Series.to_clipboard': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_clipboard.html#pandas.Series.to_clipboard',
                        'pandas.Series.to_csv': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_csv.html#pandas.Series.to_csv',
                        'pandas.Series.to_dict': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_dict.html#pandas.Series.to_dict',
                        'pandas.Series.to_excel': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_excel.html#pandas.Series.to_excel',
                        'pandas.Series.to_frame': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_frame.html#pandas.Series.to_frame',
                        'pandas.Series.to_hdf': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_hdf.html#pandas.Series.to_hdf',
                        'pandas.Series.to_json': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_json.html#pandas.Series.to_json',
                        'pandas.Series.to_latex': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_latex.html#pandas.Series.to_latex',
                        'pandas.Series.to_list': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_list.html#pandas.Series.to_list',
                        'pandas.Series.to_markdown': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_markdown.html#pandas.Series.to_markdown',
                        'pandas.Series.to_numpy': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_numpy.html#pandas.Series.to_numpy',
                        'pandas.Series.to_period': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_period.html#pandas.Series.to_period',
                        'pandas.Series.to_pickle': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_pickle.html#pandas.Series.to_pickle',
                        'pandas.Series.to_sql': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_sql.html#pandas.Series.to_sql',
                        'pandas.Series.to_string': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_string.html#pandas.Series.to_string',
                        'pandas.Series.to_timestamp': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_timestamp.html#pandas.Series.to_timestamp',
                        'pandas.Series.to_xarray': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.to_xarray.html#pandas.Series.to_xarray',
                        'pandas.Series.transform': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.transform.html#pandas.Series.transform',
                        'pandas.Series.truediv': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.truediv.html#pandas.Series.truediv',
                        'pandas.Series.truncate': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.truncate.html#pandas.Series.truncate',
                        'pandas.Series.tz_convert': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.tz_convert.html#pandas.Series.tz_convert',
                        'pandas.Series.tz_localize': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.tz_localize.html#pandas.Series.tz_localize',
                        'pandas.Series.unique': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.unique.html#pandas.Series.unique',
                        'pandas.Series.unstack': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.unstack.html#pandas.Series.unstack',
                        'pandas.Series.update': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.update.html#pandas.Series.update',
                        'pandas.Series.value_counts': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.value_counts.html#pandas.Series.value_counts',
                        'pandas.Series.var': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.var.html#pandas.Series.var',
                        'pandas.Series.view': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.view.html#pandas.Series.view',
                        'pandas.Series.where': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.where.html#pandas.Series.where',
                        'pandas.Series.xs': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.xs.html#pandas.Series.xs',
                        'pandas.SparseDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.SparseDtype.html#pandas.SparseDtype',
                        'pandas.StringDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.StringDtype.html#pandas.StringDtype',
                        'pandas.Timedelta': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.html#pandas.Timedelta',
                        'pandas.Timedelta.as_unit': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.as_unit.html#pandas.Timedelta.as_unit',
                        'pandas.Timedelta.ceil': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.ceil.html#pandas.Timedelta.ceil',
                        'pandas.Timedelta.floor': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.floor.html#pandas.Timedelta.floor',
                        'pandas.Timedelta.isoformat': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.isoformat.html#pandas.Timedelta.isoformat',
                        'pandas.Timedelta.round': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.round.html#pandas.Timedelta.round',
                        'pandas.Timedelta.to_numpy': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.to_numpy.html#pandas.Timedelta.to_numpy',
                        'pandas.Timedelta.to_pytimedelta': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.to_pytimedelta.html#pandas.Timedelta.to_pytimedelta',
                        'pandas.Timedelta.to_timedelta64': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.to_timedelta64.html#pandas.Timedelta.to_timedelta64',
                        'pandas.Timedelta.total_seconds': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.total_seconds.html#pandas.Timedelta.total_seconds',
                        'pandas.Timedelta.view': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.view.html#pandas.Timedelta.view',
                        'pandas.TimedeltaIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.html#pandas.TimedeltaIndex',
                        'pandas.TimedeltaIndex.as_unit': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.as_unit.html#pandas.TimedeltaIndex.as_unit',
                        'pandas.TimedeltaIndex.ceil': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.ceil.html#pandas.TimedeltaIndex.ceil',
                        'pandas.TimedeltaIndex.floor': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.floor.html#pandas.TimedeltaIndex.floor',
                        'pandas.TimedeltaIndex.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.mean.html#pandas.TimedeltaIndex.mean',
                        'pandas.TimedeltaIndex.round': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.round.html#pandas.TimedeltaIndex.round',
                        'pandas.TimedeltaIndex.to_frame': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.to_frame.html#pandas.TimedeltaIndex.to_frame',
                        'pandas.TimedeltaIndex.to_pytimedelta': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.to_pytimedelta.html#pandas.TimedeltaIndex.to_pytimedelta',
                        'pandas.TimedeltaIndex.to_series': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.to_series.html#pandas.TimedeltaIndex.to_series',
                        'pandas.Timestamp': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.html#pandas.Timestamp',
                        'pandas.Timestamp.as_unit': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.as_unit.html#pandas.Timestamp.as_unit',
                        'pandas.Timestamp.astimezone': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.astimezone.html#pandas.Timestamp.astimezone',
                        'pandas.Timestamp.ceil': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.ceil.html#pandas.Timestamp.ceil',
                        'pandas.Timestamp.combine': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.combine.html#pandas.Timestamp.combine',
                        'pandas.Timestamp.ctime': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.ctime.html#pandas.Timestamp.ctime',
                        'pandas.Timestamp.date': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.date.html#pandas.Timestamp.date',
                        'pandas.Timestamp.day_name': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.day_name.html#pandas.Timestamp.day_name',
                        'pandas.Timestamp.dst': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.dst.html#pandas.Timestamp.dst',
                        'pandas.Timestamp.floor': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.floor.html#pandas.Timestamp.floor',
                        'pandas.Timestamp.fromordinal': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.fromordinal.html#pandas.Timestamp.fromordinal',
                        'pandas.Timestamp.fromtimestamp': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.fromtimestamp.html#pandas.Timestamp.fromtimestamp',
                        'pandas.Timestamp.isocalendar': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.isocalendar.html#pandas.Timestamp.isocalendar',
                        'pandas.Timestamp.isoformat': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.isoformat.html#pandas.Timestamp.isoformat',
                        'pandas.Timestamp.isoweekday': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.isoweekday.html#pandas.Timestamp.isoweekday',
                        'pandas.Timestamp.month_name': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.month_name.html#pandas.Timestamp.month_name',
                        'pandas.Timestamp.normalize': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.normalize.html#pandas.Timestamp.normalize',
                        'pandas.Timestamp.now': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.now.html#pandas.Timestamp.now',
                        'pandas.Timestamp.replace': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.replace.html#pandas.Timestamp.replace',
                        'pandas.Timestamp.round': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.round.html#pandas.Timestamp.round',
                        'pandas.Timestamp.strftime': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.strftime.html#pandas.Timestamp.strftime',
                        'pandas.Timestamp.strptime': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.strptime.html#pandas.Timestamp.strptime',
                        'pandas.Timestamp.time': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.time.html#pandas.Timestamp.time',
                        'pandas.Timestamp.timestamp': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.timestamp.html#pandas.Timestamp.timestamp',
                        'pandas.Timestamp.timetuple': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.timetuple.html#pandas.Timestamp.timetuple',
                        'pandas.Timestamp.timetz': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.timetz.html#pandas.Timestamp.timetz',
                        'pandas.Timestamp.to_datetime64': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.to_datetime64.html#pandas.Timestamp.to_datetime64',
                        'pandas.Timestamp.to_julian_date': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.to_julian_date.html#pandas.Timestamp.to_julian_date',
                        'pandas.Timestamp.to_numpy': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.to_numpy.html#pandas.Timestamp.to_numpy',
                        'pandas.Timestamp.to_period': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.to_period.html#pandas.Timestamp.to_period',
                        'pandas.Timestamp.to_pydatetime': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.to_pydatetime.html#pandas.Timestamp.to_pydatetime',
                        'pandas.Timestamp.today': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.today.html#pandas.Timestamp.today',
                        'pandas.Timestamp.toordinal': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.toordinal.html#pandas.Timestamp.toordinal',
                        'pandas.Timestamp.tz_convert': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.tz_convert.html#pandas.Timestamp.tz_convert',
                        'pandas.Timestamp.tz_localize': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.tz_localize.html#pandas.Timestamp.tz_localize',
                        'pandas.Timestamp.tzname': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.tzname.html#pandas.Timestamp.tzname',
                        'pandas.Timestamp.utcfromtimestamp': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.utcfromtimestamp.html#pandas.Timestamp.utcfromtimestamp',
                        'pandas.Timestamp.utcnow': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.utcnow.html#pandas.Timestamp.utcnow',
                        'pandas.Timestamp.utcoffset': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.utcoffset.html#pandas.Timestamp.utcoffset',
                        'pandas.Timestamp.utctimetuple': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.utctimetuple.html#pandas.Timestamp.utctimetuple',
                        'pandas.Timestamp.weekday': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.weekday.html#pandas.Timestamp.weekday',
                        'pandas.UInt16Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.UInt16Dtype.html#pandas.UInt16Dtype',
                        'pandas.UInt32Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.UInt32Dtype.html#pandas.UInt32Dtype',
                        'pandas.UInt64Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.UInt64Dtype.html#pandas.UInt64Dtype',
                        'pandas.UInt8Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.UInt8Dtype.html#pandas.UInt8Dtype',
                        'pandas.array': 'https://pandas.pydata.org/docs/reference/api/pandas.array.html#pandas.array',
                        'pandas.bdate_range': 'https://pandas.pydata.org/docs/reference/api/pandas.bdate_range.html#pandas.bdate_range',
                        'pandas.concat': 'https://pandas.pydata.org/docs/reference/api/pandas.concat.html#pandas.concat',
                        'pandas.crosstab': 'https://pandas.pydata.org/docs/reference/api/pandas.crosstab.html#pandas.crosstab',
                        'pandas.cut': 'https://pandas.pydata.org/docs/reference/api/pandas.cut.html#pandas.cut',
                        'pandas.date_range': 'https://pandas.pydata.org/docs/reference/api/pandas.date_range.html#pandas.date_range',
                        'pandas.eval': 'https://pandas.pydata.org/docs/reference/api/pandas.eval.html#pandas.eval',
                        'pandas.factorize': 'https://pandas.pydata.org/docs/reference/api/pandas.factorize.html#pandas.factorize',
                        'pandas.from_dummies': 'https://pandas.pydata.org/docs/reference/api/pandas.from_dummies.html#pandas.from_dummies',
                        'pandas.get_dummies': 'https://pandas.pydata.org/docs/reference/api/pandas.get_dummies.html#pandas.get_dummies',
                        'pandas.infer_freq': 'https://pandas.pydata.org/docs/reference/api/pandas.infer_freq.html#pandas.infer_freq',
                        'pandas.interval_range': 'https://pandas.pydata.org/docs/reference/api/pandas.interval_range.html#pandas.interval_range',
                        'pandas.isna': 'https://pandas.pydata.org/docs/reference/api/pandas.isna.html#pandas.isna',
                        'pandas.isnull': 'https://pandas.pydata.org/docs/reference/api/pandas.isnull.html#pandas.isnull',
                        'pandas.json_normalize': 'https://pandas.pydata.org/docs/reference/api/pandas.json_normalize.html#pandas.json_normalize',
                        'pandas.lreshape': 'https://pandas.pydata.org/docs/reference/api/pandas.lreshape.html#pandas.lreshape',
                        'pandas.melt': 'https://pandas.pydata.org/docs/reference/api/pandas.melt.html#pandas.melt',
                        'pandas.merge': 'https://pandas.pydata.org/docs/reference/api/pandas.merge.html#pandas.merge',
                        'pandas.merge_asof': 'https://pandas.pydata.org/docs/reference/api/pandas.merge_asof.html#pandas.merge_asof',
                        'pandas.merge_ordered': 'https://pandas.pydata.org/docs/reference/api/pandas.merge_ordered.html#pandas.merge_ordered',
                        'pandas.notna': 'https://pandas.pydata.org/docs/reference/api/pandas.notna.html#pandas.notna',
                        'pandas.notnull': 'https://pandas.pydata.org/docs/reference/api/pandas.notnull.html#pandas.notnull',
                        'pandas.option_context': 'https://pandas.pydata.org/docs/reference/api/pandas.option_context.html#pandas.option_context',
                        'pandas.period_range': 'https://pandas.pydata.org/docs/reference/api/pandas.period_range.html#pandas.period_range',
                        'pandas.pivot': 'https://pandas.pydata.org/docs/reference/api/pandas.pivot.html#pandas.pivot',
                        'pandas.pivot_table': 'https://pandas.pydata.org/docs/reference/api/pandas.pivot_table.html#pandas.pivot_table',
                        'pandas.qcut': 'https://pandas.pydata.org/docs/reference/api/pandas.qcut.html#pandas.qcut',
                        'pandas.read_clipboard': 'https://pandas.pydata.org/docs/reference/api/pandas.read_clipboard.html#pandas.read_clipboard',
                        'pandas.read_csv': 'https://pandas.pydata.org/docs/reference/api/pandas.read_csv.html#pandas.read_csv',
                        'pandas.read_excel': 'https://pandas.pydata.org/docs/reference/api/pandas.read_excel.html#pandas.read_excel',
                        'pandas.read_feather': 'https://pandas.pydata.org/docs/reference/api/pandas.read_feather.html#pandas.read_feather',
                        'pandas.read_fwf': 'https://pandas.pydata.org/docs/reference/api/pandas.read_fwf.html#pandas.read_fwf',
                        'pandas.read_gbq': 'https://pandas.pydata.org/docs/reference/api/pandas.read_gbq.html#pandas.read_gbq',
                        'pandas.read_hdf': 'https://pandas.pydata.org/docs/reference/api/pandas.read_hdf.html#pandas.read_hdf',
                        'pandas.read_html': 'https://pandas.pydata.org/docs/reference/api/pandas.read_html.html#pandas.read_html',
                        'pandas.read_json': 'https://pandas.pydata.org/docs/reference/api/pandas.read_json.html#pandas.read_json',
                        'pandas.read_orc': 'https://pandas.pydata.org/docs/reference/api/pandas.read_orc.html#pandas.read_orc',
                        'pandas.read_parquet': 'https://pandas.pydata.org/docs/reference/api/pandas.read_parquet.html#pandas.read_parquet',
                        'pandas.read_pickle': 'https://pandas.pydata.org/docs/reference/api/pandas.read_pickle.html#pandas.read_pickle',
                        'pandas.read_sas': 'https://pandas.pydata.org/docs/reference/api/pandas.read_sas.html#pandas.read_sas',
                        'pandas.read_spss': 'https://pandas.pydata.org/docs/reference/api/pandas.read_spss.html#pandas.read_spss',
                        'pandas.read_sql': 'https://pandas.pydata.org/docs/reference/api/pandas.read_sql.html#pandas.read_sql',
                        'pandas.read_sql_query': 'https://pandas.pydata.org/docs/reference/api/pandas.read_sql_query.html#pandas.read_sql_query',
                        'pandas.read_sql_table': 'https://pandas.pydata.org/docs/reference/api/pandas.read_sql_table.html#pandas.read_sql_table',
                        'pandas.read_stata': 'https://pandas.pydata.org/docs/reference/api/pandas.read_stata.html#pandas.read_stata',
                        'pandas.read_table': 'https://pandas.pydata.org/docs/reference/api/pandas.read_table.html#pandas.read_table',
                        'pandas.read_xml': 'https://pandas.pydata.org/docs/reference/api/pandas.read_xml.html#pandas.read_xml',
                        'pandas.set_eng_float_format': 'https://pandas.pydata.org/docs/reference/api/pandas.set_eng_float_format.html#pandas.set_eng_float_format',
                        'pandas.show_versions': 'https://pandas.pydata.org/docs/reference/api/pandas.show_versions.html#pandas.show_versions',
                        'pandas.test': 'https://pandas.pydata.org/docs/reference/api/pandas.test.html#pandas.test',
                        'pandas.timedelta_range': 'https://pandas.pydata.org/docs/reference/api/pandas.timedelta_range.html#pandas.timedelta_range',
                        'pandas.to_datetime': 'https://pandas.pydata.org/docs/reference/api/pandas.to_datetime.html#pandas.to_datetime',
                        'pandas.to_numeric': 'https://pandas.pydata.org/docs/reference/api/pandas.to_numeric.html#pandas.to_numeric',
                        'pandas.to_timedelta': 'https://pandas.pydata.org/docs/reference/api/pandas.to_timedelta.html#pandas.to_timedelta',
                        'pandas.unique': 'https://pandas.pydata.org/docs/reference/api/pandas.unique.html#pandas.unique',
                        'pandas.wide_to_long': 'https://pandas.pydata.org/docs/reference/api/pandas.wide_to_long.html#pandas.wide_to_long'},
            'pandas.DataFrame': { 'pandas.DataFrame.plot.area': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.area.html#pandas.DataFrame.plot.area',
                                  'pandas.DataFrame.plot.bar': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.bar.html#pandas.DataFrame.plot.bar',
                                  'pandas.DataFrame.plot.barh': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.barh.html#pandas.DataFrame.plot.barh',
                                  'pandas.DataFrame.plot.box': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.box.html#pandas.DataFrame.plot.box',
                                  'pandas.DataFrame.plot.density': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.density.html#pandas.DataFrame.plot.density',
                                  'pandas.DataFrame.plot.hexbin': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.hexbin.html#pandas.DataFrame.plot.hexbin',
                                  'pandas.DataFrame.plot.hist': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.hist.html#pandas.DataFrame.plot.hist',
                                  'pandas.DataFrame.plot.kde': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.kde.html#pandas.DataFrame.plot.kde',
                                  'pandas.DataFrame.plot.line': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.line.html#pandas.DataFrame.plot.line',
                                  'pandas.DataFrame.plot.pie': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.pie.html#pandas.DataFrame.plot.pie',
                                  'pandas.DataFrame.plot.scatter': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.plot.scatter.html#pandas.DataFrame.plot.scatter',
                                  'pandas.DataFrame.sparse.from_spmatrix': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sparse.from_spmatrix.html#pandas.DataFrame.sparse.from_spmatrix',
                                  'pandas.DataFrame.sparse.to_coo': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sparse.to_coo.html#pandas.DataFrame.sparse.to_coo',
                                  'pandas.DataFrame.sparse.to_dense': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.sparse.to_dense.html#pandas.DataFrame.sparse.to_dense'},
            'pandas.Series': { 'pandas.Series.cat.add_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cat.add_categories.html#pandas.Series.cat.add_categories',
                               'pandas.Series.cat.as_ordered': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cat.as_ordered.html#pandas.Series.cat.as_ordered',
                               'pandas.Series.cat.as_unordered': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cat.as_unordered.html#pandas.Series.cat.as_unordered',
                               'pandas.Series.cat.remove_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cat.remove_categories.html#pandas.Series.cat.remove_categories',
                               'pandas.Series.cat.remove_unused_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cat.remove_unused_categories.html#pandas.Series.cat.remove_unused_categories',
                               'pandas.Series.cat.rename_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cat.rename_categories.html#pandas.Series.cat.rename_categories',
                               'pandas.Series.cat.reorder_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cat.reorder_categories.html#pandas.Series.cat.reorder_categories',
                               'pandas.Series.cat.set_categories': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.cat.set_categories.html#pandas.Series.cat.set_categories',
                               'pandas.Series.dt.as_unit': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.as_unit.html#pandas.Series.dt.as_unit',
                               'pandas.Series.dt.ceil': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.ceil.html#pandas.Series.dt.ceil',
                               'pandas.Series.dt.day_name': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.day_name.html#pandas.Series.dt.day_name',
                               'pandas.Series.dt.floor': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.floor.html#pandas.Series.dt.floor',
                               'pandas.Series.dt.isocalendar': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.isocalendar.html#pandas.Series.dt.isocalendar',
                               'pandas.Series.dt.month_name': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.month_name.html#pandas.Series.dt.month_name',
                               'pandas.Series.dt.normalize': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.normalize.html#pandas.Series.dt.normalize',
                               'pandas.Series.dt.round': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.round.html#pandas.Series.dt.round',
                               'pandas.Series.dt.strftime': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.strftime.html#pandas.Series.dt.strftime',
                               'pandas.Series.dt.to_period': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.to_period.html#pandas.Series.dt.to_period',
                               'pandas.Series.dt.to_pydatetime': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.to_pydatetime.html#pandas.Series.dt.to_pydatetime',
                               'pandas.Series.dt.to_pytimedelta': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.to_pytimedelta.html#pandas.Series.dt.to_pytimedelta',
                               'pandas.Series.dt.total_seconds': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.total_seconds.html#pandas.Series.dt.total_seconds',
                               'pandas.Series.dt.tz_convert': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.tz_convert.html#pandas.Series.dt.tz_convert',
                               'pandas.Series.dt.tz_localize': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.dt.tz_localize.html#pandas.Series.dt.tz_localize',
                               'pandas.Series.list.__getitem__': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.list.__getitem__.html#pandas.Series.list.__getitem__',
                               'pandas.Series.list.flatten': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.list.flatten.html#pandas.Series.list.flatten',
                               'pandas.Series.list.len': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.list.len.html#pandas.Series.list.len',
                               'pandas.Series.plot.area': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.area.html#pandas.Series.plot.area',
                               'pandas.Series.plot.bar': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.bar.html#pandas.Series.plot.bar',
                               'pandas.Series.plot.barh': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.barh.html#pandas.Series.plot.barh',
                               'pandas.Series.plot.box': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.box.html#pandas.Series.plot.box',
                               'pandas.Series.plot.density': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.density.html#pandas.Series.plot.density',
                               'pandas.Series.plot.hist': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.hist.html#pandas.Series.plot.hist',
                               'pandas.Series.plot.kde': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.kde.html#pandas.Series.plot.kde',
                               'pandas.Series.plot.line': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.line.html#pandas.Series.plot.line',
                               'pandas.Series.plot.pie': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.plot.pie.html#pandas.Series.plot.pie',
                               'pandas.Series.sparse.from_coo': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.sparse.from_coo.html#pandas.Series.sparse.from_coo',
                               'pandas.Series.sparse.to_coo': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.sparse.to_coo.html#pandas.Series.sparse.to_coo',
                               'pandas.Series.str.capitalize': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.capitalize.html#pandas.Series.str.capitalize',
                               'pandas.Series.str.casefold': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.casefold.html#pandas.Series.str.casefold',
                               'pandas.Series.str.cat': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.cat.html#pandas.Series.str.cat',
                               'pandas.Series.str.center': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.center.html#pandas.Series.str.center',
                               'pandas.Series.str.contains': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.contains.html#pandas.Series.str.contains',
                               'pandas.Series.str.count': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.count.html#pandas.Series.str.count',
                               'pandas.Series.str.decode': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.decode.html#pandas.Series.str.decode',
                               'pandas.Series.str.encode': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.encode.html#pandas.Series.str.encode',
                               'pandas.Series.str.endswith': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.endswith.html#pandas.Series.str.endswith',
                               'pandas.Series.str.extract': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.extract.html#pandas.Series.str.extract',
                               'pandas.Series.str.extractall': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.extractall.html#pandas.Series.str.extractall',
                               'pandas.Series.str.find': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.find.html#pandas.Series.str.find',
                               'pandas.Series.str.findall': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.findall.html#pandas.Series.str.findall',
                               'pandas.Series.str.fullmatch': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.fullmatch.html#pandas.Series.str.fullmatch',
                               'pandas.Series.str.get': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.get.html#pandas.Series.str.get',
                               'pandas.Series.str.get_dummies': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.get_dummies.html#pandas.Series.str.get_dummies',
                               'pandas.Series.str.index': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.index.html#pandas.Series.str.index',
                               'pandas.Series.str.isalnum': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.isalnum.html#pandas.Series.str.isalnum',
                               'pandas.Series.str.isalpha': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.isalpha.html#pandas.Series.str.isalpha',
                               'pandas.Series.str.isdecimal': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.isdecimal.html#pandas.Series.str.isdecimal',
                               'pandas.Series.str.isdigit': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.isdigit.html#pandas.Series.str.isdigit',
                               'pandas.Series.str.islower': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.islower.html#pandas.Series.str.islower',
                               'pandas.Series.str.isnumeric': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.isnumeric.html#pandas.Series.str.isnumeric',
                               'pandas.Series.str.isspace': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.isspace.html#pandas.Series.str.isspace',
                               'pandas.Series.str.istitle': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.istitle.html#pandas.Series.str.istitle',
                               'pandas.Series.str.isupper': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.isupper.html#pandas.Series.str.isupper',
                               'pandas.Series.str.join': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.join.html#pandas.Series.str.join',
                               'pandas.Series.str.len': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.len.html#pandas.Series.str.len',
                               'pandas.Series.str.ljust': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.ljust.html#pandas.Series.str.ljust',
                               'pandas.Series.str.lower': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.lower.html#pandas.Series.str.lower',
                               'pandas.Series.str.lstrip': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.lstrip.html#pandas.Series.str.lstrip',
                               'pandas.Series.str.match': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.match.html#pandas.Series.str.match',
                               'pandas.Series.str.normalize': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.normalize.html#pandas.Series.str.normalize',
                               'pandas.Series.str.pad': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.pad.html#pandas.Series.str.pad',
                               'pandas.Series.str.partition': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.partition.html#pandas.Series.str.partition',
                               'pandas.Series.str.removeprefix': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.removeprefix.html#pandas.Series.str.removeprefix',
                               'pandas.Series.str.removesuffix': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.removesuffix.html#pandas.Series.str.removesuffix',
                               'pandas.Series.str.repeat': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.repeat.html#pandas.Series.str.repeat',
                               'pandas.Series.str.replace': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.replace.html#pandas.Series.str.replace',
                               'pandas.Series.str.rfind': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.rfind.html#pandas.Series.str.rfind',
                               'pandas.Series.str.rindex': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.rindex.html#pandas.Series.str.rindex',
                               'pandas.Series.str.rjust': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.rjust.html#pandas.Series.str.rjust',
                               'pandas.Series.str.rpartition': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.rpartition.html#pandas.Series.str.rpartition',
                               'pandas.Series.str.rsplit': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.rsplit.html#pandas.Series.str.rsplit',
                               'pandas.Series.str.rstrip': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.rstrip.html#pandas.Series.str.rstrip',
                               'pandas.Series.str.slice': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.slice.html#pandas.Series.str.slice',
                               'pandas.Series.str.slice_replace': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.slice_replace.html#pandas.Series.str.slice_replace',
                               'pandas.Series.str.split': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.split.html#pandas.Series.str.split',
                               'pandas.Series.str.startswith': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.startswith.html#pandas.Series.str.startswith',
                               'pandas.Series.str.strip': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.strip.html#pandas.Series.str.strip',
                               'pandas.Series.str.swapcase': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.swapcase.html#pandas.Series.str.swapcase',
                               'pandas.Series.str.title': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.title.html#pandas.Series.str.title',
                               'pandas.Series.str.translate': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.translate.html#pandas.Series.str.translate',
                               'pandas.Series.str.upper': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.upper.html#pandas.Series.str.upper',
                               'pandas.Series.str.wrap': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.wrap.html#pandas.Series.str.wrap',
                               'pandas.Series.str.zfill': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.str.zfill.html#pandas.Series.str.zfill',
                               'pandas.Series.struct.explode': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.struct.explode.html#pandas.Series.struct.explode',
                               'pandas.Series.struct.field': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.struct.field.html#pandas.Series.struct.field'},
            'pandas._config.config': { 'pandas._config.config.option_context': 'https://pandas.pydata.org/docs/reference/api/pandas.option_context.html#pandas.option_context'},
            'pandas._libs.interval': {'pandas._libs.interval.Interval': 'https://pandas.pydata.org/docs/reference/api/pandas.Interval.html#pandas.Interval'},
            'pandas._libs.tslibs.offsets': { 'pandas._libs.tslibs.offsets.BQuarterBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.html#pandas.tseries.offsets.BQuarterBegin',
                                             'pandas._libs.tslibs.offsets.BQuarterEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.html#pandas.tseries.offsets.BQuarterEnd',
                                             'pandas._libs.tslibs.offsets.BYearBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.html#pandas.tseries.offsets.BYearBegin',
                                             'pandas._libs.tslibs.offsets.BYearEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.html#pandas.tseries.offsets.BYearEnd',
                                             'pandas._libs.tslibs.offsets.BusinessDay': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.html#pandas.tseries.offsets.BusinessDay',
                                             'pandas._libs.tslibs.offsets.BusinessHour': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.html#pandas.tseries.offsets.BusinessHour',
                                             'pandas._libs.tslibs.offsets.BusinessMonthBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.html#pandas.tseries.offsets.BusinessMonthBegin',
                                             'pandas._libs.tslibs.offsets.BusinessMonthEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.html#pandas.tseries.offsets.BusinessMonthEnd',
                                             'pandas._libs.tslibs.offsets.CustomBusinessDay': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.html#pandas.tseries.offsets.CustomBusinessDay',
                                             'pandas._libs.tslibs.offsets.CustomBusinessHour': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.html#pandas.tseries.offsets.CustomBusinessHour',
                                             'pandas._libs.tslibs.offsets.CustomBusinessMonthBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.html#pandas.tseries.offsets.CustomBusinessMonthBegin',
                                             'pandas._libs.tslibs.offsets.CustomBusinessMonthEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.html#pandas.tseries.offsets.CustomBusinessMonthEnd',
                                             'pandas._libs.tslibs.offsets.DateOffset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.html#pandas.tseries.offsets.DateOffset',
                                             'pandas._libs.tslibs.offsets.Day': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.html#pandas.tseries.offsets.Day',
                                             'pandas._libs.tslibs.offsets.Easter': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.html#pandas.tseries.offsets.Easter',
                                             'pandas._libs.tslibs.offsets.FY5253': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.html#pandas.tseries.offsets.FY5253',
                                             'pandas._libs.tslibs.offsets.FY5253Quarter': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.html#pandas.tseries.offsets.FY5253Quarter',
                                             'pandas._libs.tslibs.offsets.Hour': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.html#pandas.tseries.offsets.Hour',
                                             'pandas._libs.tslibs.offsets.LastWeekOfMonth': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.html#pandas.tseries.offsets.LastWeekOfMonth',
                                             'pandas._libs.tslibs.offsets.Micro': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.html#pandas.tseries.offsets.Micro',
                                             'pandas._libs.tslibs.offsets.Milli': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.html#pandas.tseries.offsets.Milli',
                                             'pandas._libs.tslibs.offsets.Minute': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.html#pandas.tseries.offsets.Minute',
                                             'pandas._libs.tslibs.offsets.MonthBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.html#pandas.tseries.offsets.MonthBegin',
                                             'pandas._libs.tslibs.offsets.MonthEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.html#pandas.tseries.offsets.MonthEnd',
                                             'pandas._libs.tslibs.offsets.Nano': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.html#pandas.tseries.offsets.Nano',
                                             'pandas._libs.tslibs.offsets.QuarterBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.html#pandas.tseries.offsets.QuarterBegin',
                                             'pandas._libs.tslibs.offsets.QuarterEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.html#pandas.tseries.offsets.QuarterEnd',
                                             'pandas._libs.tslibs.offsets.Second': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.html#pandas.tseries.offsets.Second',
                                             'pandas._libs.tslibs.offsets.SemiMonthBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.html#pandas.tseries.offsets.SemiMonthBegin',
                                             'pandas._libs.tslibs.offsets.SemiMonthEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.html#pandas.tseries.offsets.SemiMonthEnd',
                                             'pandas._libs.tslibs.offsets.Tick': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.html#pandas.tseries.offsets.Tick',
                                             'pandas._libs.tslibs.offsets.Week': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.html#pandas.tseries.offsets.Week',
                                             'pandas._libs.tslibs.offsets.WeekOfMonth': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.html#pandas.tseries.offsets.WeekOfMonth',
                                             'pandas._libs.tslibs.offsets.YearBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.html#pandas.tseries.offsets.YearBegin',
                                             'pandas._libs.tslibs.offsets.YearEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.html#pandas.tseries.offsets.YearEnd'},
            'pandas._libs.tslibs.period': { 'pandas._libs.tslibs.period.Period': 'https://pandas.pydata.org/docs/reference/api/pandas.Period.html#pandas.Period'},
            'pandas._libs.tslibs.timedeltas': { 'pandas._libs.tslibs.timedeltas.Timedelta': 'https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.html#pandas.Timedelta'},
            'pandas._libs.tslibs.timestamps': { 'pandas._libs.tslibs.timestamps.Timestamp': 'https://pandas.pydata.org/docs/reference/api/pandas.Timestamp.html#pandas.Timestamp'},
            'pandas.api.extensions': { 'pandas.api.extensions.ExtensionArray': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.html#pandas.api.extensions.ExtensionArray',
                                       'pandas.api.extensions.ExtensionArray._accumulate': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._accumulate.html#pandas.api.extensions.ExtensionArray._accumulate',
                                       'pandas.api.extensions.ExtensionArray._concat_same_type': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._concat_same_type.html#pandas.api.extensions.ExtensionArray._concat_same_type',
                                       'pandas.api.extensions.ExtensionArray._explode': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._explode.html#pandas.api.extensions.ExtensionArray._explode',
                                       'pandas.api.extensions.ExtensionArray._formatter': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._formatter.html#pandas.api.extensions.ExtensionArray._formatter',
                                       'pandas.api.extensions.ExtensionArray._from_factorized': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._from_factorized.html#pandas.api.extensions.ExtensionArray._from_factorized',
                                       'pandas.api.extensions.ExtensionArray._from_sequence': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._from_sequence.html#pandas.api.extensions.ExtensionArray._from_sequence',
                                       'pandas.api.extensions.ExtensionArray._from_sequence_of_strings': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._from_sequence_of_strings.html#pandas.api.extensions.ExtensionArray._from_sequence_of_strings',
                                       'pandas.api.extensions.ExtensionArray._hash_pandas_object': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._hash_pandas_object.html#pandas.api.extensions.ExtensionArray._hash_pandas_object',
                                       'pandas.api.extensions.ExtensionArray._pad_or_backfill': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._pad_or_backfill.html#pandas.api.extensions.ExtensionArray._pad_or_backfill',
                                       'pandas.api.extensions.ExtensionArray._reduce': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._reduce.html#pandas.api.extensions.ExtensionArray._reduce',
                                       'pandas.api.extensions.ExtensionArray._values_for_argsort': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._values_for_argsort.html#pandas.api.extensions.ExtensionArray._values_for_argsort',
                                       'pandas.api.extensions.ExtensionArray._values_for_factorize': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray._values_for_factorize.html#pandas.api.extensions.ExtensionArray._values_for_factorize',
                                       'pandas.api.extensions.ExtensionArray.argsort': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.argsort.html#pandas.api.extensions.ExtensionArray.argsort',
                                       'pandas.api.extensions.ExtensionArray.astype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.astype.html#pandas.api.extensions.ExtensionArray.astype',
                                       'pandas.api.extensions.ExtensionArray.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.copy.html#pandas.api.extensions.ExtensionArray.copy',
                                       'pandas.api.extensions.ExtensionArray.dropna': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.dropna.html#pandas.api.extensions.ExtensionArray.dropna',
                                       'pandas.api.extensions.ExtensionArray.duplicated': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.duplicated.html#pandas.api.extensions.ExtensionArray.duplicated',
                                       'pandas.api.extensions.ExtensionArray.equals': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.equals.html#pandas.api.extensions.ExtensionArray.equals',
                                       'pandas.api.extensions.ExtensionArray.factorize': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.factorize.html#pandas.api.extensions.ExtensionArray.factorize',
                                       'pandas.api.extensions.ExtensionArray.fillna': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.fillna.html#pandas.api.extensions.ExtensionArray.fillna',
                                       'pandas.api.extensions.ExtensionArray.insert': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.insert.html#pandas.api.extensions.ExtensionArray.insert',
                                       'pandas.api.extensions.ExtensionArray.interpolate': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.interpolate.html#pandas.api.extensions.ExtensionArray.interpolate',
                                       'pandas.api.extensions.ExtensionArray.isin': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.isin.html#pandas.api.extensions.ExtensionArray.isin',
                                       'pandas.api.extensions.ExtensionArray.isna': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.isna.html#pandas.api.extensions.ExtensionArray.isna',
                                       'pandas.api.extensions.ExtensionArray.ravel': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.ravel.html#pandas.api.extensions.ExtensionArray.ravel',
                                       'pandas.api.extensions.ExtensionArray.repeat': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.repeat.html#pandas.api.extensions.ExtensionArray.repeat',
                                       'pandas.api.extensions.ExtensionArray.searchsorted': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.searchsorted.html#pandas.api.extensions.ExtensionArray.searchsorted',
                                       'pandas.api.extensions.ExtensionArray.shift': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.shift.html#pandas.api.extensions.ExtensionArray.shift',
                                       'pandas.api.extensions.ExtensionArray.take': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.take.html#pandas.api.extensions.ExtensionArray.take',
                                       'pandas.api.extensions.ExtensionArray.tolist': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.tolist.html#pandas.api.extensions.ExtensionArray.tolist',
                                       'pandas.api.extensions.ExtensionArray.unique': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.unique.html#pandas.api.extensions.ExtensionArray.unique',
                                       'pandas.api.extensions.ExtensionArray.view': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.view.html#pandas.api.extensions.ExtensionArray.view',
                                       'pandas.api.extensions.ExtensionDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionDtype.html#pandas.api.extensions.ExtensionDtype',
                                       'pandas.api.extensions.register_dataframe_accessor': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.register_dataframe_accessor.html#pandas.api.extensions.register_dataframe_accessor',
                                       'pandas.api.extensions.register_extension_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.register_extension_dtype.html#pandas.api.extensions.register_extension_dtype',
                                       'pandas.api.extensions.register_index_accessor': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.register_index_accessor.html#pandas.api.extensions.register_index_accessor',
                                       'pandas.api.extensions.register_series_accessor': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.register_series_accessor.html#pandas.api.extensions.register_series_accessor'},
            'pandas.api.indexers': { 'pandas.api.indexers.BaseIndexer': 'https://pandas.pydata.org/docs/reference/api/pandas.api.indexers.BaseIndexer.html#pandas.api.indexers.BaseIndexer',
                                     'pandas.api.indexers.FixedForwardWindowIndexer': 'https://pandas.pydata.org/docs/reference/api/pandas.api.indexers.FixedForwardWindowIndexer.html#pandas.api.indexers.FixedForwardWindowIndexer',
                                     'pandas.api.indexers.VariableOffsetWindowIndexer': 'https://pandas.pydata.org/docs/reference/api/pandas.api.indexers.VariableOffsetWindowIndexer.html#pandas.api.indexers.VariableOffsetWindowIndexer',
                                     'pandas.api.indexers.check_array_indexer': 'https://pandas.pydata.org/docs/reference/api/pandas.api.indexers.check_array_indexer.html#pandas.api.indexers.check_array_indexer'},
            'pandas.api.interchange': { 'pandas.api.interchange.from_dataframe': 'https://pandas.pydata.org/docs/reference/api/pandas.api.interchange.from_dataframe.html#pandas.api.interchange.from_dataframe'},
            'pandas.api.types': { 'pandas.api.types.infer_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.infer_dtype.html#pandas.api.types.infer_dtype',
                                  'pandas.api.types.is_any_real_numeric_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_any_real_numeric_dtype.html#pandas.api.types.is_any_real_numeric_dtype',
                                  'pandas.api.types.is_bool': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_bool.html#pandas.api.types.is_bool',
                                  'pandas.api.types.is_bool_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_bool_dtype.html#pandas.api.types.is_bool_dtype',
                                  'pandas.api.types.is_categorical_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_categorical_dtype.html#pandas.api.types.is_categorical_dtype',
                                  'pandas.api.types.is_complex': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_complex.html#pandas.api.types.is_complex',
                                  'pandas.api.types.is_complex_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_complex_dtype.html#pandas.api.types.is_complex_dtype',
                                  'pandas.api.types.is_datetime64_any_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_datetime64_any_dtype.html#pandas.api.types.is_datetime64_any_dtype',
                                  'pandas.api.types.is_datetime64_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_datetime64_dtype.html#pandas.api.types.is_datetime64_dtype',
                                  'pandas.api.types.is_datetime64_ns_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_datetime64_ns_dtype.html#pandas.api.types.is_datetime64_ns_dtype',
                                  'pandas.api.types.is_datetime64tz_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_datetime64tz_dtype.html#pandas.api.types.is_datetime64tz_dtype',
                                  'pandas.api.types.is_dict_like': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_dict_like.html#pandas.api.types.is_dict_like',
                                  'pandas.api.types.is_extension_array_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_extension_array_dtype.html#pandas.api.types.is_extension_array_dtype',
                                  'pandas.api.types.is_file_like': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_file_like.html#pandas.api.types.is_file_like',
                                  'pandas.api.types.is_float': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_float.html#pandas.api.types.is_float',
                                  'pandas.api.types.is_float_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_float_dtype.html#pandas.api.types.is_float_dtype',
                                  'pandas.api.types.is_hashable': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_hashable.html#pandas.api.types.is_hashable',
                                  'pandas.api.types.is_int64_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_int64_dtype.html#pandas.api.types.is_int64_dtype',
                                  'pandas.api.types.is_integer': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_integer.html#pandas.api.types.is_integer',
                                  'pandas.api.types.is_integer_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_integer_dtype.html#pandas.api.types.is_integer_dtype',
                                  'pandas.api.types.is_interval': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_interval.html#pandas.api.types.is_interval',
                                  'pandas.api.types.is_interval_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_interval_dtype.html#pandas.api.types.is_interval_dtype',
                                  'pandas.api.types.is_iterator': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_iterator.html#pandas.api.types.is_iterator',
                                  'pandas.api.types.is_list_like': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_list_like.html#pandas.api.types.is_list_like',
                                  'pandas.api.types.is_named_tuple': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_named_tuple.html#pandas.api.types.is_named_tuple',
                                  'pandas.api.types.is_number': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_number.html#pandas.api.types.is_number',
                                  'pandas.api.types.is_numeric_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_numeric_dtype.html#pandas.api.types.is_numeric_dtype',
                                  'pandas.api.types.is_object_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_object_dtype.html#pandas.api.types.is_object_dtype',
                                  'pandas.api.types.is_period_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_period_dtype.html#pandas.api.types.is_period_dtype',
                                  'pandas.api.types.is_re': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_re.html#pandas.api.types.is_re',
                                  'pandas.api.types.is_re_compilable': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_re_compilable.html#pandas.api.types.is_re_compilable',
                                  'pandas.api.types.is_scalar': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_scalar.html#pandas.api.types.is_scalar',
                                  'pandas.api.types.is_signed_integer_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_signed_integer_dtype.html#pandas.api.types.is_signed_integer_dtype',
                                  'pandas.api.types.is_sparse': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_sparse.html#pandas.api.types.is_sparse',
                                  'pandas.api.types.is_string_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_string_dtype.html#pandas.api.types.is_string_dtype',
                                  'pandas.api.types.is_timedelta64_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_timedelta64_dtype.html#pandas.api.types.is_timedelta64_dtype',
                                  'pandas.api.types.is_timedelta64_ns_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_timedelta64_ns_dtype.html#pandas.api.types.is_timedelta64_ns_dtype',
                                  'pandas.api.types.is_unsigned_integer_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.is_unsigned_integer_dtype.html#pandas.api.types.is_unsigned_integer_dtype',
                                  'pandas.api.types.pandas_dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.pandas_dtype.html#pandas.api.types.pandas_dtype',
                                  'pandas.api.types.union_categoricals': 'https://pandas.pydata.org/docs/reference/api/pandas.api.types.union_categoricals.html#pandas.api.types.union_categoricals'},
            'pandas.arrays': { 'pandas.arrays.ArrowExtensionArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.ArrowExtensionArray.html#pandas.arrays.ArrowExtensionArray',
                               'pandas.arrays.ArrowStringArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.ArrowStringArray.html#pandas.arrays.ArrowStringArray',
                               'pandas.arrays.BooleanArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.BooleanArray.html#pandas.arrays.BooleanArray',
                               'pandas.arrays.DatetimeArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.DatetimeArray.html#pandas.arrays.DatetimeArray',
                               'pandas.arrays.FloatingArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.FloatingArray.html#pandas.arrays.FloatingArray',
                               'pandas.arrays.IntegerArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntegerArray.html#pandas.arrays.IntegerArray',
                               'pandas.arrays.IntervalArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntervalArray.html#pandas.arrays.IntervalArray',
                               'pandas.arrays.IntervalArray.contains': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntervalArray.contains.html#pandas.arrays.IntervalArray.contains',
                               'pandas.arrays.IntervalArray.from_arrays': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntervalArray.from_arrays.html#pandas.arrays.IntervalArray.from_arrays',
                               'pandas.arrays.IntervalArray.from_breaks': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntervalArray.from_breaks.html#pandas.arrays.IntervalArray.from_breaks',
                               'pandas.arrays.IntervalArray.from_tuples': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntervalArray.from_tuples.html#pandas.arrays.IntervalArray.from_tuples',
                               'pandas.arrays.IntervalArray.overlaps': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntervalArray.overlaps.html#pandas.arrays.IntervalArray.overlaps',
                               'pandas.arrays.IntervalArray.set_closed': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntervalArray.set_closed.html#pandas.arrays.IntervalArray.set_closed',
                               'pandas.arrays.IntervalArray.to_tuples': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntervalArray.to_tuples.html#pandas.arrays.IntervalArray.to_tuples',
                               'pandas.arrays.NumpyExtensionArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.NumpyExtensionArray.html#pandas.arrays.NumpyExtensionArray',
                               'pandas.arrays.PeriodArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.PeriodArray.html#pandas.arrays.PeriodArray',
                               'pandas.arrays.SparseArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.SparseArray.html#pandas.arrays.SparseArray',
                               'pandas.arrays.StringArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.StringArray.html#pandas.arrays.StringArray',
                               'pandas.arrays.TimedeltaArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.TimedeltaArray.html#pandas.arrays.TimedeltaArray'},
            'pandas.core.arrays.arrow.array': { 'pandas.core.arrays.arrow.array.ArrowExtensionArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.ArrowExtensionArray.html#pandas.arrays.ArrowExtensionArray'},
            'pandas.core.arrays.base': { 'pandas.core.arrays.base.ExtensionArray': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionArray.html#pandas.api.extensions.ExtensionArray'},
            'pandas.core.arrays.boolean': { 'pandas.core.arrays.boolean.BooleanArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.BooleanArray.html#pandas.arrays.BooleanArray',
                                            'pandas.core.arrays.boolean.BooleanDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.BooleanDtype.html#pandas.BooleanDtype'},
            'pandas.core.arrays.categorical': { 'pandas.core.arrays.categorical.Categorical': 'https://pandas.pydata.org/docs/reference/api/pandas.Categorical.html#pandas.Categorical'},
            'pandas.core.arrays.datetimes': { 'pandas.core.arrays.datetimes.DatetimeArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.DatetimeArray.html#pandas.arrays.DatetimeArray'},
            'pandas.core.arrays.floating': { 'pandas.core.arrays.floating.Float32Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Float32Dtype.html#pandas.Float32Dtype',
                                             'pandas.core.arrays.floating.Float64Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Float64Dtype.html#pandas.Float64Dtype',
                                             'pandas.core.arrays.floating.FloatingArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.FloatingArray.html#pandas.arrays.FloatingArray'},
            'pandas.core.arrays.integer': { 'pandas.core.arrays.integer.Int16Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Int16Dtype.html#pandas.Int16Dtype',
                                            'pandas.core.arrays.integer.Int32Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Int32Dtype.html#pandas.Int32Dtype',
                                            'pandas.core.arrays.integer.Int64Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Int64Dtype.html#pandas.Int64Dtype',
                                            'pandas.core.arrays.integer.Int8Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.Int8Dtype.html#pandas.Int8Dtype',
                                            'pandas.core.arrays.integer.IntegerArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntegerArray.html#pandas.arrays.IntegerArray',
                                            'pandas.core.arrays.integer.UInt16Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.UInt16Dtype.html#pandas.UInt16Dtype',
                                            'pandas.core.arrays.integer.UInt32Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.UInt32Dtype.html#pandas.UInt32Dtype',
                                            'pandas.core.arrays.integer.UInt64Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.UInt64Dtype.html#pandas.UInt64Dtype',
                                            'pandas.core.arrays.integer.UInt8Dtype': 'https://pandas.pydata.org/docs/reference/api/pandas.UInt8Dtype.html#pandas.UInt8Dtype'},
            'pandas.core.arrays.interval': { 'pandas.core.arrays.interval.IntervalArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.IntervalArray.html#pandas.arrays.IntervalArray'},
            'pandas.core.arrays.numpy_': { 'pandas.core.arrays.numpy_.NumpyExtensionArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.NumpyExtensionArray.html#pandas.arrays.NumpyExtensionArray'},
            'pandas.core.arrays.period': { 'pandas.core.arrays.period.PeriodArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.PeriodArray.html#pandas.arrays.PeriodArray'},
            'pandas.core.arrays.sparse.array': { 'pandas.core.arrays.sparse.array.SparseArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.SparseArray.html#pandas.arrays.SparseArray'},
            'pandas.core.arrays.string_': { 'pandas.core.arrays.string_.StringArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.StringArray.html#pandas.arrays.StringArray',
                                            'pandas.core.arrays.string_.StringDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.StringDtype.html#pandas.StringDtype'},
            'pandas.core.arrays.string_arrow': { 'pandas.core.arrays.string_arrow.ArrowStringArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.ArrowStringArray.html#pandas.arrays.ArrowStringArray'},
            'pandas.core.arrays.timedeltas': { 'pandas.core.arrays.timedeltas.TimedeltaArray': 'https://pandas.pydata.org/docs/reference/api/pandas.arrays.TimedeltaArray.html#pandas.arrays.TimedeltaArray'},
            'pandas.core.dtypes.base': { 'pandas.core.dtypes.base.ExtensionDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.api.extensions.ExtensionDtype.html#pandas.api.extensions.ExtensionDtype'},
            'pandas.core.dtypes.dtypes': { 'pandas.core.dtypes.dtypes.ArrowDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.ArrowDtype.html#pandas.ArrowDtype',
                                           'pandas.core.dtypes.dtypes.CategoricalDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalDtype.html#pandas.CategoricalDtype',
                                           'pandas.core.dtypes.dtypes.DatetimeTZDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeTZDtype.html#pandas.DatetimeTZDtype',
                                           'pandas.core.dtypes.dtypes.IntervalDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalDtype.html#pandas.IntervalDtype',
                                           'pandas.core.dtypes.dtypes.PeriodDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.PeriodDtype.html#pandas.PeriodDtype',
                                           'pandas.core.dtypes.dtypes.SparseDtype': 'https://pandas.pydata.org/docs/reference/api/pandas.SparseDtype.html#pandas.SparseDtype'},
            'pandas.core.flags': {'pandas.core.flags.Flags': 'https://pandas.pydata.org/docs/reference/api/pandas.Flags.html#pandas.Flags'},
            'pandas.core.frame': {'pandas.core.frame.DataFrame': 'https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.html#pandas.DataFrame'},
            'pandas.core.groupby': { 'pandas.core.groupby.DataFrameGroupBy.__iter__': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.__iter__.html#pandas.core.groupby.DataFrameGroupBy.__iter__',
                                     'pandas.core.groupby.DataFrameGroupBy.agg': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.agg.html#pandas.core.groupby.DataFrameGroupBy.agg',
                                     'pandas.core.groupby.DataFrameGroupBy.aggregate': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.aggregate.html#pandas.core.groupby.DataFrameGroupBy.aggregate',
                                     'pandas.core.groupby.DataFrameGroupBy.all': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.all.html#pandas.core.groupby.DataFrameGroupBy.all',
                                     'pandas.core.groupby.DataFrameGroupBy.any': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.any.html#pandas.core.groupby.DataFrameGroupBy.any',
                                     'pandas.core.groupby.DataFrameGroupBy.apply': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.apply.html#pandas.core.groupby.DataFrameGroupBy.apply',
                                     'pandas.core.groupby.DataFrameGroupBy.bfill': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.bfill.html#pandas.core.groupby.DataFrameGroupBy.bfill',
                                     'pandas.core.groupby.DataFrameGroupBy.boxplot': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.boxplot.html#pandas.core.groupby.DataFrameGroupBy.boxplot',
                                     'pandas.core.groupby.DataFrameGroupBy.corr': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.corr.html#pandas.core.groupby.DataFrameGroupBy.corr',
                                     'pandas.core.groupby.DataFrameGroupBy.corrwith': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.corrwith.html#pandas.core.groupby.DataFrameGroupBy.corrwith',
                                     'pandas.core.groupby.DataFrameGroupBy.count': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.count.html#pandas.core.groupby.DataFrameGroupBy.count',
                                     'pandas.core.groupby.DataFrameGroupBy.cov': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.cov.html#pandas.core.groupby.DataFrameGroupBy.cov',
                                     'pandas.core.groupby.DataFrameGroupBy.cumcount': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.cumcount.html#pandas.core.groupby.DataFrameGroupBy.cumcount',
                                     'pandas.core.groupby.DataFrameGroupBy.cummax': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.cummax.html#pandas.core.groupby.DataFrameGroupBy.cummax',
                                     'pandas.core.groupby.DataFrameGroupBy.cummin': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.cummin.html#pandas.core.groupby.DataFrameGroupBy.cummin',
                                     'pandas.core.groupby.DataFrameGroupBy.cumprod': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.cumprod.html#pandas.core.groupby.DataFrameGroupBy.cumprod',
                                     'pandas.core.groupby.DataFrameGroupBy.cumsum': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.cumsum.html#pandas.core.groupby.DataFrameGroupBy.cumsum',
                                     'pandas.core.groupby.DataFrameGroupBy.describe': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.describe.html#pandas.core.groupby.DataFrameGroupBy.describe',
                                     'pandas.core.groupby.DataFrameGroupBy.diff': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.diff.html#pandas.core.groupby.DataFrameGroupBy.diff',
                                     'pandas.core.groupby.DataFrameGroupBy.ffill': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.ffill.html#pandas.core.groupby.DataFrameGroupBy.ffill',
                                     'pandas.core.groupby.DataFrameGroupBy.fillna': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.fillna.html#pandas.core.groupby.DataFrameGroupBy.fillna',
                                     'pandas.core.groupby.DataFrameGroupBy.filter': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.filter.html#pandas.core.groupby.DataFrameGroupBy.filter',
                                     'pandas.core.groupby.DataFrameGroupBy.first': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.first.html#pandas.core.groupby.DataFrameGroupBy.first',
                                     'pandas.core.groupby.DataFrameGroupBy.get_group': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.get_group.html#pandas.core.groupby.DataFrameGroupBy.get_group',
                                     'pandas.core.groupby.DataFrameGroupBy.head': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.head.html#pandas.core.groupby.DataFrameGroupBy.head',
                                     'pandas.core.groupby.DataFrameGroupBy.hist': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.hist.html#pandas.core.groupby.DataFrameGroupBy.hist',
                                     'pandas.core.groupby.DataFrameGroupBy.idxmax': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.idxmax.html#pandas.core.groupby.DataFrameGroupBy.idxmax',
                                     'pandas.core.groupby.DataFrameGroupBy.idxmin': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.idxmin.html#pandas.core.groupby.DataFrameGroupBy.idxmin',
                                     'pandas.core.groupby.DataFrameGroupBy.last': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.last.html#pandas.core.groupby.DataFrameGroupBy.last',
                                     'pandas.core.groupby.DataFrameGroupBy.max': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.max.html#pandas.core.groupby.DataFrameGroupBy.max',
                                     'pandas.core.groupby.DataFrameGroupBy.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.mean.html#pandas.core.groupby.DataFrameGroupBy.mean',
                                     'pandas.core.groupby.DataFrameGroupBy.median': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.median.html#pandas.core.groupby.DataFrameGroupBy.median',
                                     'pandas.core.groupby.DataFrameGroupBy.min': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.min.html#pandas.core.groupby.DataFrameGroupBy.min',
                                     'pandas.core.groupby.DataFrameGroupBy.ngroup': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.ngroup.html#pandas.core.groupby.DataFrameGroupBy.ngroup',
                                     'pandas.core.groupby.DataFrameGroupBy.nunique': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.nunique.html#pandas.core.groupby.DataFrameGroupBy.nunique',
                                     'pandas.core.groupby.DataFrameGroupBy.ohlc': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.ohlc.html#pandas.core.groupby.DataFrameGroupBy.ohlc',
                                     'pandas.core.groupby.DataFrameGroupBy.pct_change': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.pct_change.html#pandas.core.groupby.DataFrameGroupBy.pct_change',
                                     'pandas.core.groupby.DataFrameGroupBy.pipe': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.pipe.html#pandas.core.groupby.DataFrameGroupBy.pipe',
                                     'pandas.core.groupby.DataFrameGroupBy.prod': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.prod.html#pandas.core.groupby.DataFrameGroupBy.prod',
                                     'pandas.core.groupby.DataFrameGroupBy.quantile': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.quantile.html#pandas.core.groupby.DataFrameGroupBy.quantile',
                                     'pandas.core.groupby.DataFrameGroupBy.rank': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.rank.html#pandas.core.groupby.DataFrameGroupBy.rank',
                                     'pandas.core.groupby.DataFrameGroupBy.resample': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.resample.html#pandas.core.groupby.DataFrameGroupBy.resample',
                                     'pandas.core.groupby.DataFrameGroupBy.rolling': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.rolling.html#pandas.core.groupby.DataFrameGroupBy.rolling',
                                     'pandas.core.groupby.DataFrameGroupBy.sample': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.sample.html#pandas.core.groupby.DataFrameGroupBy.sample',
                                     'pandas.core.groupby.DataFrameGroupBy.sem': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.sem.html#pandas.core.groupby.DataFrameGroupBy.sem',
                                     'pandas.core.groupby.DataFrameGroupBy.shift': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.shift.html#pandas.core.groupby.DataFrameGroupBy.shift',
                                     'pandas.core.groupby.DataFrameGroupBy.size': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.size.html#pandas.core.groupby.DataFrameGroupBy.size',
                                     'pandas.core.groupby.DataFrameGroupBy.skew': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.skew.html#pandas.core.groupby.DataFrameGroupBy.skew',
                                     'pandas.core.groupby.DataFrameGroupBy.std': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.std.html#pandas.core.groupby.DataFrameGroupBy.std',
                                     'pandas.core.groupby.DataFrameGroupBy.sum': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.sum.html#pandas.core.groupby.DataFrameGroupBy.sum',
                                     'pandas.core.groupby.DataFrameGroupBy.tail': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.tail.html#pandas.core.groupby.DataFrameGroupBy.tail',
                                     'pandas.core.groupby.DataFrameGroupBy.take': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.take.html#pandas.core.groupby.DataFrameGroupBy.take',
                                     'pandas.core.groupby.DataFrameGroupBy.transform': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.transform.html#pandas.core.groupby.DataFrameGroupBy.transform',
                                     'pandas.core.groupby.DataFrameGroupBy.value_counts': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.value_counts.html#pandas.core.groupby.DataFrameGroupBy.value_counts',
                                     'pandas.core.groupby.DataFrameGroupBy.var': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.DataFrameGroupBy.var.html#pandas.core.groupby.DataFrameGroupBy.var',
                                     'pandas.core.groupby.SeriesGroupBy.__iter__': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.__iter__.html#pandas.core.groupby.SeriesGroupBy.__iter__',
                                     'pandas.core.groupby.SeriesGroupBy.agg': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.agg.html#pandas.core.groupby.SeriesGroupBy.agg',
                                     'pandas.core.groupby.SeriesGroupBy.aggregate': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.aggregate.html#pandas.core.groupby.SeriesGroupBy.aggregate',
                                     'pandas.core.groupby.SeriesGroupBy.all': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.all.html#pandas.core.groupby.SeriesGroupBy.all',
                                     'pandas.core.groupby.SeriesGroupBy.any': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.any.html#pandas.core.groupby.SeriesGroupBy.any',
                                     'pandas.core.groupby.SeriesGroupBy.apply': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.apply.html#pandas.core.groupby.SeriesGroupBy.apply',
                                     'pandas.core.groupby.SeriesGroupBy.bfill': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.bfill.html#pandas.core.groupby.SeriesGroupBy.bfill',
                                     'pandas.core.groupby.SeriesGroupBy.corr': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.corr.html#pandas.core.groupby.SeriesGroupBy.corr',
                                     'pandas.core.groupby.SeriesGroupBy.count': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.count.html#pandas.core.groupby.SeriesGroupBy.count',
                                     'pandas.core.groupby.SeriesGroupBy.cov': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.cov.html#pandas.core.groupby.SeriesGroupBy.cov',
                                     'pandas.core.groupby.SeriesGroupBy.cumcount': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.cumcount.html#pandas.core.groupby.SeriesGroupBy.cumcount',
                                     'pandas.core.groupby.SeriesGroupBy.cummax': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.cummax.html#pandas.core.groupby.SeriesGroupBy.cummax',
                                     'pandas.core.groupby.SeriesGroupBy.cummin': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.cummin.html#pandas.core.groupby.SeriesGroupBy.cummin',
                                     'pandas.core.groupby.SeriesGroupBy.cumprod': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.cumprod.html#pandas.core.groupby.SeriesGroupBy.cumprod',
                                     'pandas.core.groupby.SeriesGroupBy.cumsum': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.cumsum.html#pandas.core.groupby.SeriesGroupBy.cumsum',
                                     'pandas.core.groupby.SeriesGroupBy.describe': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.describe.html#pandas.core.groupby.SeriesGroupBy.describe',
                                     'pandas.core.groupby.SeriesGroupBy.diff': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.diff.html#pandas.core.groupby.SeriesGroupBy.diff',
                                     'pandas.core.groupby.SeriesGroupBy.ffill': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.ffill.html#pandas.core.groupby.SeriesGroupBy.ffill',
                                     'pandas.core.groupby.SeriesGroupBy.fillna': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.fillna.html#pandas.core.groupby.SeriesGroupBy.fillna',
                                     'pandas.core.groupby.SeriesGroupBy.filter': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.filter.html#pandas.core.groupby.SeriesGroupBy.filter',
                                     'pandas.core.groupby.SeriesGroupBy.first': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.first.html#pandas.core.groupby.SeriesGroupBy.first',
                                     'pandas.core.groupby.SeriesGroupBy.get_group': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.get_group.html#pandas.core.groupby.SeriesGroupBy.get_group',
                                     'pandas.core.groupby.SeriesGroupBy.head': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.head.html#pandas.core.groupby.SeriesGroupBy.head',
                                     'pandas.core.groupby.SeriesGroupBy.hist': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.hist.html#pandas.core.groupby.SeriesGroupBy.hist',
                                     'pandas.core.groupby.SeriesGroupBy.idxmax': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.idxmax.html#pandas.core.groupby.SeriesGroupBy.idxmax',
                                     'pandas.core.groupby.SeriesGroupBy.idxmin': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.idxmin.html#pandas.core.groupby.SeriesGroupBy.idxmin',
                                     'pandas.core.groupby.SeriesGroupBy.last': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.last.html#pandas.core.groupby.SeriesGroupBy.last',
                                     'pandas.core.groupby.SeriesGroupBy.max': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.max.html#pandas.core.groupby.SeriesGroupBy.max',
                                     'pandas.core.groupby.SeriesGroupBy.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.mean.html#pandas.core.groupby.SeriesGroupBy.mean',
                                     'pandas.core.groupby.SeriesGroupBy.median': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.median.html#pandas.core.groupby.SeriesGroupBy.median',
                                     'pandas.core.groupby.SeriesGroupBy.min': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.min.html#pandas.core.groupby.SeriesGroupBy.min',
                                     'pandas.core.groupby.SeriesGroupBy.ngroup': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.ngroup.html#pandas.core.groupby.SeriesGroupBy.ngroup',
                                     'pandas.core.groupby.SeriesGroupBy.nlargest': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.nlargest.html#pandas.core.groupby.SeriesGroupBy.nlargest',
                                     'pandas.core.groupby.SeriesGroupBy.nsmallest': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.nsmallest.html#pandas.core.groupby.SeriesGroupBy.nsmallest',
                                     'pandas.core.groupby.SeriesGroupBy.nunique': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.nunique.html#pandas.core.groupby.SeriesGroupBy.nunique',
                                     'pandas.core.groupby.SeriesGroupBy.ohlc': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.ohlc.html#pandas.core.groupby.SeriesGroupBy.ohlc',
                                     'pandas.core.groupby.SeriesGroupBy.pct_change': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.pct_change.html#pandas.core.groupby.SeriesGroupBy.pct_change',
                                     'pandas.core.groupby.SeriesGroupBy.pipe': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.pipe.html#pandas.core.groupby.SeriesGroupBy.pipe',
                                     'pandas.core.groupby.SeriesGroupBy.prod': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.prod.html#pandas.core.groupby.SeriesGroupBy.prod',
                                     'pandas.core.groupby.SeriesGroupBy.quantile': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.quantile.html#pandas.core.groupby.SeriesGroupBy.quantile',
                                     'pandas.core.groupby.SeriesGroupBy.rank': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.rank.html#pandas.core.groupby.SeriesGroupBy.rank',
                                     'pandas.core.groupby.SeriesGroupBy.resample': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.resample.html#pandas.core.groupby.SeriesGroupBy.resample',
                                     'pandas.core.groupby.SeriesGroupBy.rolling': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.rolling.html#pandas.core.groupby.SeriesGroupBy.rolling',
                                     'pandas.core.groupby.SeriesGroupBy.sample': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.sample.html#pandas.core.groupby.SeriesGroupBy.sample',
                                     'pandas.core.groupby.SeriesGroupBy.sem': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.sem.html#pandas.core.groupby.SeriesGroupBy.sem',
                                     'pandas.core.groupby.SeriesGroupBy.shift': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.shift.html#pandas.core.groupby.SeriesGroupBy.shift',
                                     'pandas.core.groupby.SeriesGroupBy.size': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.size.html#pandas.core.groupby.SeriesGroupBy.size',
                                     'pandas.core.groupby.SeriesGroupBy.skew': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.skew.html#pandas.core.groupby.SeriesGroupBy.skew',
                                     'pandas.core.groupby.SeriesGroupBy.std': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.std.html#pandas.core.groupby.SeriesGroupBy.std',
                                     'pandas.core.groupby.SeriesGroupBy.sum': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.sum.html#pandas.core.groupby.SeriesGroupBy.sum',
                                     'pandas.core.groupby.SeriesGroupBy.tail': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.tail.html#pandas.core.groupby.SeriesGroupBy.tail',
                                     'pandas.core.groupby.SeriesGroupBy.take': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.take.html#pandas.core.groupby.SeriesGroupBy.take',
                                     'pandas.core.groupby.SeriesGroupBy.transform': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.transform.html#pandas.core.groupby.SeriesGroupBy.transform',
                                     'pandas.core.groupby.SeriesGroupBy.unique': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.unique.html#pandas.core.groupby.SeriesGroupBy.unique',
                                     'pandas.core.groupby.SeriesGroupBy.value_counts': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.value_counts.html#pandas.core.groupby.SeriesGroupBy.value_counts',
                                     'pandas.core.groupby.SeriesGroupBy.var': 'https://pandas.pydata.org/docs/reference/api/pandas.core.groupby.SeriesGroupBy.var.html#pandas.core.groupby.SeriesGroupBy.var'},
            'pandas.core.groupby.generic': { 'pandas.core.groupby.generic.NamedAgg': 'https://pandas.pydata.org/docs/reference/api/pandas.NamedAgg.html#pandas.NamedAgg'},
            'pandas.core.groupby.grouper': { 'pandas.core.groupby.grouper.Grouper': 'https://pandas.pydata.org/docs/reference/api/pandas.Grouper.html#pandas.Grouper'},
            'pandas.core.indexers.objects': { 'pandas.core.indexers.objects.BaseIndexer': 'https://pandas.pydata.org/docs/reference/api/pandas.api.indexers.BaseIndexer.html#pandas.api.indexers.BaseIndexer',
                                              'pandas.core.indexers.objects.FixedForwardWindowIndexer': 'https://pandas.pydata.org/docs/reference/api/pandas.api.indexers.FixedForwardWindowIndexer.html#pandas.api.indexers.FixedForwardWindowIndexer',
                                              'pandas.core.indexers.objects.VariableOffsetWindowIndexer': 'https://pandas.pydata.org/docs/reference/api/pandas.api.indexers.VariableOffsetWindowIndexer.html#pandas.api.indexers.VariableOffsetWindowIndexer'},
            'pandas.core.indexes.base': {'pandas.core.indexes.base.Index': 'https://pandas.pydata.org/docs/reference/api/pandas.Index.html#pandas.Index'},
            'pandas.core.indexes.category': { 'pandas.core.indexes.category.CategoricalIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.CategoricalIndex.html#pandas.CategoricalIndex'},
            'pandas.core.indexes.datetimes': { 'pandas.core.indexes.datetimes.DatetimeIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.DatetimeIndex.html#pandas.DatetimeIndex'},
            'pandas.core.indexes.interval': { 'pandas.core.indexes.interval.IntervalIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.IntervalIndex.html#pandas.IntervalIndex'},
            'pandas.core.indexes.multi': { 'pandas.core.indexes.multi.MultiIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.MultiIndex.html#pandas.MultiIndex'},
            'pandas.core.indexes.period': { 'pandas.core.indexes.period.PeriodIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.PeriodIndex.html#pandas.PeriodIndex'},
            'pandas.core.indexes.range': { 'pandas.core.indexes.range.RangeIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.RangeIndex.html#pandas.RangeIndex'},
            'pandas.core.indexes.timedeltas': { 'pandas.core.indexes.timedeltas.TimedeltaIndex': 'https://pandas.pydata.org/docs/reference/api/pandas.TimedeltaIndex.html#pandas.TimedeltaIndex'},
            'pandas.core.resample': { 'pandas.core.resample.Resampler.__iter__': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.__iter__.html#pandas.core.resample.Resampler.__iter__',
                                      'pandas.core.resample.Resampler.aggregate': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.aggregate.html#pandas.core.resample.Resampler.aggregate',
                                      'pandas.core.resample.Resampler.apply': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.apply.html#pandas.core.resample.Resampler.apply',
                                      'pandas.core.resample.Resampler.asfreq': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.asfreq.html#pandas.core.resample.Resampler.asfreq',
                                      'pandas.core.resample.Resampler.bfill': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.bfill.html#pandas.core.resample.Resampler.bfill',
                                      'pandas.core.resample.Resampler.count': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.count.html#pandas.core.resample.Resampler.count',
                                      'pandas.core.resample.Resampler.ffill': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.ffill.html#pandas.core.resample.Resampler.ffill',
                                      'pandas.core.resample.Resampler.fillna': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.fillna.html#pandas.core.resample.Resampler.fillna',
                                      'pandas.core.resample.Resampler.first': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.first.html#pandas.core.resample.Resampler.first',
                                      'pandas.core.resample.Resampler.get_group': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.get_group.html#pandas.core.resample.Resampler.get_group',
                                      'pandas.core.resample.Resampler.interpolate': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.interpolate.html#pandas.core.resample.Resampler.interpolate',
                                      'pandas.core.resample.Resampler.last': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.last.html#pandas.core.resample.Resampler.last',
                                      'pandas.core.resample.Resampler.max': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.max.html#pandas.core.resample.Resampler.max',
                                      'pandas.core.resample.Resampler.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.mean.html#pandas.core.resample.Resampler.mean',
                                      'pandas.core.resample.Resampler.median': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.median.html#pandas.core.resample.Resampler.median',
                                      'pandas.core.resample.Resampler.min': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.min.html#pandas.core.resample.Resampler.min',
                                      'pandas.core.resample.Resampler.nearest': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.nearest.html#pandas.core.resample.Resampler.nearest',
                                      'pandas.core.resample.Resampler.nunique': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.nunique.html#pandas.core.resample.Resampler.nunique',
                                      'pandas.core.resample.Resampler.ohlc': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.ohlc.html#pandas.core.resample.Resampler.ohlc',
                                      'pandas.core.resample.Resampler.pipe': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.pipe.html#pandas.core.resample.Resampler.pipe',
                                      'pandas.core.resample.Resampler.prod': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.prod.html#pandas.core.resample.Resampler.prod',
                                      'pandas.core.resample.Resampler.quantile': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.quantile.html#pandas.core.resample.Resampler.quantile',
                                      'pandas.core.resample.Resampler.sem': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.sem.html#pandas.core.resample.Resampler.sem',
                                      'pandas.core.resample.Resampler.size': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.size.html#pandas.core.resample.Resampler.size',
                                      'pandas.core.resample.Resampler.std': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.std.html#pandas.core.resample.Resampler.std',
                                      'pandas.core.resample.Resampler.sum': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.sum.html#pandas.core.resample.Resampler.sum',
                                      'pandas.core.resample.Resampler.transform': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.transform.html#pandas.core.resample.Resampler.transform',
                                      'pandas.core.resample.Resampler.var': 'https://pandas.pydata.org/docs/reference/api/pandas.core.resample.Resampler.var.html#pandas.core.resample.Resampler.var'},
            'pandas.core.series': {'pandas.core.series.Series': 'https://pandas.pydata.org/docs/reference/api/pandas.Series.html#pandas.Series'},
            'pandas.core.window.ewm': { 'pandas.core.window.ewm.ExponentialMovingWindow.corr': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.ewm.ExponentialMovingWindow.corr.html#pandas.core.window.ewm.ExponentialMovingWindow.corr',
                                        'pandas.core.window.ewm.ExponentialMovingWindow.cov': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.ewm.ExponentialMovingWindow.cov.html#pandas.core.window.ewm.ExponentialMovingWindow.cov',
                                        'pandas.core.window.ewm.ExponentialMovingWindow.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.ewm.ExponentialMovingWindow.mean.html#pandas.core.window.ewm.ExponentialMovingWindow.mean',
                                        'pandas.core.window.ewm.ExponentialMovingWindow.std': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.ewm.ExponentialMovingWindow.std.html#pandas.core.window.ewm.ExponentialMovingWindow.std',
                                        'pandas.core.window.ewm.ExponentialMovingWindow.sum': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.ewm.ExponentialMovingWindow.sum.html#pandas.core.window.ewm.ExponentialMovingWindow.sum',
                                        'pandas.core.window.ewm.ExponentialMovingWindow.var': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.ewm.ExponentialMovingWindow.var.html#pandas.core.window.ewm.ExponentialMovingWindow.var'},
            'pandas.core.window.expanding': { 'pandas.core.window.expanding.Expanding.aggregate': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.aggregate.html#pandas.core.window.expanding.Expanding.aggregate',
                                              'pandas.core.window.expanding.Expanding.apply': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.apply.html#pandas.core.window.expanding.Expanding.apply',
                                              'pandas.core.window.expanding.Expanding.corr': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.corr.html#pandas.core.window.expanding.Expanding.corr',
                                              'pandas.core.window.expanding.Expanding.count': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.count.html#pandas.core.window.expanding.Expanding.count',
                                              'pandas.core.window.expanding.Expanding.cov': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.cov.html#pandas.core.window.expanding.Expanding.cov',
                                              'pandas.core.window.expanding.Expanding.kurt': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.kurt.html#pandas.core.window.expanding.Expanding.kurt',
                                              'pandas.core.window.expanding.Expanding.max': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.max.html#pandas.core.window.expanding.Expanding.max',
                                              'pandas.core.window.expanding.Expanding.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.mean.html#pandas.core.window.expanding.Expanding.mean',
                                              'pandas.core.window.expanding.Expanding.median': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.median.html#pandas.core.window.expanding.Expanding.median',
                                              'pandas.core.window.expanding.Expanding.min': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.min.html#pandas.core.window.expanding.Expanding.min',
                                              'pandas.core.window.expanding.Expanding.quantile': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.quantile.html#pandas.core.window.expanding.Expanding.quantile',
                                              'pandas.core.window.expanding.Expanding.rank': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.rank.html#pandas.core.window.expanding.Expanding.rank',
                                              'pandas.core.window.expanding.Expanding.sem': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.sem.html#pandas.core.window.expanding.Expanding.sem',
                                              'pandas.core.window.expanding.Expanding.skew': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.skew.html#pandas.core.window.expanding.Expanding.skew',
                                              'pandas.core.window.expanding.Expanding.std': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.std.html#pandas.core.window.expanding.Expanding.std',
                                              'pandas.core.window.expanding.Expanding.sum': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.sum.html#pandas.core.window.expanding.Expanding.sum',
                                              'pandas.core.window.expanding.Expanding.var': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.expanding.Expanding.var.html#pandas.core.window.expanding.Expanding.var'},
            'pandas.core.window.rolling': { 'pandas.core.window.rolling.Rolling.aggregate': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.aggregate.html#pandas.core.window.rolling.Rolling.aggregate',
                                            'pandas.core.window.rolling.Rolling.apply': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.apply.html#pandas.core.window.rolling.Rolling.apply',
                                            'pandas.core.window.rolling.Rolling.corr': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.corr.html#pandas.core.window.rolling.Rolling.corr',
                                            'pandas.core.window.rolling.Rolling.count': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.count.html#pandas.core.window.rolling.Rolling.count',
                                            'pandas.core.window.rolling.Rolling.cov': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.cov.html#pandas.core.window.rolling.Rolling.cov',
                                            'pandas.core.window.rolling.Rolling.kurt': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.kurt.html#pandas.core.window.rolling.Rolling.kurt',
                                            'pandas.core.window.rolling.Rolling.max': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.max.html#pandas.core.window.rolling.Rolling.max',
                                            'pandas.core.window.rolling.Rolling.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.mean.html#pandas.core.window.rolling.Rolling.mean',
                                            'pandas.core.window.rolling.Rolling.median': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.median.html#pandas.core.window.rolling.Rolling.median',
                                            'pandas.core.window.rolling.Rolling.min': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.min.html#pandas.core.window.rolling.Rolling.min',
                                            'pandas.core.window.rolling.Rolling.quantile': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.quantile.html#pandas.core.window.rolling.Rolling.quantile',
                                            'pandas.core.window.rolling.Rolling.rank': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.rank.html#pandas.core.window.rolling.Rolling.rank',
                                            'pandas.core.window.rolling.Rolling.sem': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.sem.html#pandas.core.window.rolling.Rolling.sem',
                                            'pandas.core.window.rolling.Rolling.skew': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.skew.html#pandas.core.window.rolling.Rolling.skew',
                                            'pandas.core.window.rolling.Rolling.std': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.std.html#pandas.core.window.rolling.Rolling.std',
                                            'pandas.core.window.rolling.Rolling.sum': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.sum.html#pandas.core.window.rolling.Rolling.sum',
                                            'pandas.core.window.rolling.Rolling.var': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Rolling.var.html#pandas.core.window.rolling.Rolling.var',
                                            'pandas.core.window.rolling.Window.mean': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Window.mean.html#pandas.core.window.rolling.Window.mean',
                                            'pandas.core.window.rolling.Window.std': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Window.std.html#pandas.core.window.rolling.Window.std',
                                            'pandas.core.window.rolling.Window.sum': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Window.sum.html#pandas.core.window.rolling.Window.sum',
                                            'pandas.core.window.rolling.Window.var': 'https://pandas.pydata.org/docs/reference/api/pandas.core.window.rolling.Window.var.html#pandas.core.window.rolling.Window.var'},
            'pandas.io.excel._base': { 'pandas.io.excel._base.ExcelFile': 'https://pandas.pydata.org/docs/reference/api/pandas.ExcelFile.html#pandas.ExcelFile',
                                       'pandas.io.excel._base.ExcelWriter': 'https://pandas.pydata.org/docs/reference/api/pandas.ExcelWriter.html#pandas.ExcelWriter'},
            'pandas.io.formats.style': { 'pandas.io.formats.style.Styler': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.html#pandas.io.formats.style.Styler',
                                         'pandas.io.formats.style.Styler.apply': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.apply.html#pandas.io.formats.style.Styler.apply',
                                         'pandas.io.formats.style.Styler.apply_index': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.apply_index.html#pandas.io.formats.style.Styler.apply_index',
                                         'pandas.io.formats.style.Styler.background_gradient': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.background_gradient.html#pandas.io.formats.style.Styler.background_gradient',
                                         'pandas.io.formats.style.Styler.bar': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.bar.html#pandas.io.formats.style.Styler.bar',
                                         'pandas.io.formats.style.Styler.clear': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.clear.html#pandas.io.formats.style.Styler.clear',
                                         'pandas.io.formats.style.Styler.concat': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.concat.html#pandas.io.formats.style.Styler.concat',
                                         'pandas.io.formats.style.Styler.export': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.export.html#pandas.io.formats.style.Styler.export',
                                         'pandas.io.formats.style.Styler.format': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.format.html#pandas.io.formats.style.Styler.format',
                                         'pandas.io.formats.style.Styler.format_index': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.format_index.html#pandas.io.formats.style.Styler.format_index',
                                         'pandas.io.formats.style.Styler.from_custom_template': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.from_custom_template.html#pandas.io.formats.style.Styler.from_custom_template',
                                         'pandas.io.formats.style.Styler.hide': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.hide.html#pandas.io.formats.style.Styler.hide',
                                         'pandas.io.formats.style.Styler.highlight_between': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.highlight_between.html#pandas.io.formats.style.Styler.highlight_between',
                                         'pandas.io.formats.style.Styler.highlight_max': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.highlight_max.html#pandas.io.formats.style.Styler.highlight_max',
                                         'pandas.io.formats.style.Styler.highlight_min': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.highlight_min.html#pandas.io.formats.style.Styler.highlight_min',
                                         'pandas.io.formats.style.Styler.highlight_null': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.highlight_null.html#pandas.io.formats.style.Styler.highlight_null',
                                         'pandas.io.formats.style.Styler.highlight_quantile': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.highlight_quantile.html#pandas.io.formats.style.Styler.highlight_quantile',
                                         'pandas.io.formats.style.Styler.map': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.map.html#pandas.io.formats.style.Styler.map',
                                         'pandas.io.formats.style.Styler.map_index': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.map_index.html#pandas.io.formats.style.Styler.map_index',
                                         'pandas.io.formats.style.Styler.pipe': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.pipe.html#pandas.io.formats.style.Styler.pipe',
                                         'pandas.io.formats.style.Styler.relabel_index': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.relabel_index.html#pandas.io.formats.style.Styler.relabel_index',
                                         'pandas.io.formats.style.Styler.set_caption': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.set_caption.html#pandas.io.formats.style.Styler.set_caption',
                                         'pandas.io.formats.style.Styler.set_properties': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.set_properties.html#pandas.io.formats.style.Styler.set_properties',
                                         'pandas.io.formats.style.Styler.set_sticky': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.set_sticky.html#pandas.io.formats.style.Styler.set_sticky',
                                         'pandas.io.formats.style.Styler.set_table_attributes': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.set_table_attributes.html#pandas.io.formats.style.Styler.set_table_attributes',
                                         'pandas.io.formats.style.Styler.set_table_styles': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.set_table_styles.html#pandas.io.formats.style.Styler.set_table_styles',
                                         'pandas.io.formats.style.Styler.set_td_classes': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.set_td_classes.html#pandas.io.formats.style.Styler.set_td_classes',
                                         'pandas.io.formats.style.Styler.set_tooltips': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.set_tooltips.html#pandas.io.formats.style.Styler.set_tooltips',
                                         'pandas.io.formats.style.Styler.set_uuid': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.set_uuid.html#pandas.io.formats.style.Styler.set_uuid',
                                         'pandas.io.formats.style.Styler.text_gradient': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.text_gradient.html#pandas.io.formats.style.Styler.text_gradient',
                                         'pandas.io.formats.style.Styler.to_excel': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.to_excel.html#pandas.io.formats.style.Styler.to_excel',
                                         'pandas.io.formats.style.Styler.to_html': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.to_html.html#pandas.io.formats.style.Styler.to_html',
                                         'pandas.io.formats.style.Styler.to_latex': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.to_latex.html#pandas.io.formats.style.Styler.to_latex',
                                         'pandas.io.formats.style.Styler.to_string': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.to_string.html#pandas.io.formats.style.Styler.to_string',
                                         'pandas.io.formats.style.Styler.use': 'https://pandas.pydata.org/docs/reference/api/pandas.io.formats.style.Styler.use.html#pandas.io.formats.style.Styler.use'},
            'pandas.io.json': { 'pandas.io.json.build_table_schema': 'https://pandas.pydata.org/docs/reference/api/pandas.io.json.build_table_schema.html#pandas.io.json.build_table_schema'},
            'pandas.io.stata': { 'pandas.io.stata.StataReader.value_labels': 'https://pandas.pydata.org/docs/reference/api/pandas.io.stata.StataReader.value_labels.html#pandas.io.stata.StataReader.value_labels',
                                 'pandas.io.stata.StataReader.variable_labels': 'https://pandas.pydata.org/docs/reference/api/pandas.io.stata.StataReader.variable_labels.html#pandas.io.stata.StataReader.variable_labels',
                                 'pandas.io.stata.StataWriter.write_file': 'https://pandas.pydata.org/docs/reference/api/pandas.io.stata.StataWriter.write_file.html#pandas.io.stata.StataWriter.write_file'},
            'pandas.plotting': { 'pandas.plotting.andrews_curves': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.andrews_curves.html#pandas.plotting.andrews_curves',
                                 'pandas.plotting.autocorrelation_plot': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.autocorrelation_plot.html#pandas.plotting.autocorrelation_plot',
                                 'pandas.plotting.bootstrap_plot': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.bootstrap_plot.html#pandas.plotting.bootstrap_plot',
                                 'pandas.plotting.boxplot': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.boxplot.html#pandas.plotting.boxplot',
                                 'pandas.plotting.deregister_matplotlib_converters': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.deregister_matplotlib_converters.html#pandas.plotting.deregister_matplotlib_converters',
                                 'pandas.plotting.lag_plot': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.lag_plot.html#pandas.plotting.lag_plot',
                                 'pandas.plotting.parallel_coordinates': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.parallel_coordinates.html#pandas.plotting.parallel_coordinates',
                                 'pandas.plotting.radviz': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.radviz.html#pandas.plotting.radviz',
                                 'pandas.plotting.register_matplotlib_converters': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.register_matplotlib_converters.html#pandas.plotting.register_matplotlib_converters',
                                 'pandas.plotting.scatter_matrix': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.scatter_matrix.html#pandas.plotting.scatter_matrix',
                                 'pandas.plotting.table': 'https://pandas.pydata.org/docs/reference/api/pandas.plotting.table.html#pandas.plotting.table'},
            'pandas.testing': { 'pandas.testing.assert_extension_array_equal': 'https://pandas.pydata.org/docs/reference/api/pandas.testing.assert_extension_array_equal.html#pandas.testing.assert_extension_array_equal',
                                'pandas.testing.assert_frame_equal': 'https://pandas.pydata.org/docs/reference/api/pandas.testing.assert_frame_equal.html#pandas.testing.assert_frame_equal',
                                'pandas.testing.assert_index_equal': 'https://pandas.pydata.org/docs/reference/api/pandas.testing.assert_index_equal.html#pandas.testing.assert_index_equal',
                                'pandas.testing.assert_series_equal': 'https://pandas.pydata.org/docs/reference/api/pandas.testing.assert_series_equal.html#pandas.testing.assert_series_equal'},
            'pandas.tseries.api': { 'pandas.tseries.api.guess_datetime_format': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.api.guess_datetime_format.html#pandas.tseries.api.guess_datetime_format'},
            'pandas.tseries.frequencies': { 'pandas.tseries.frequencies.to_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.frequencies.to_offset.html#pandas.tseries.frequencies.to_offset'},
            'pandas.tseries.offsets': { 'pandas.tseries.offsets.BQuarterBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.html#pandas.tseries.offsets.BQuarterBegin',
                                        'pandas.tseries.offsets.BQuarterBegin.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.copy.html#pandas.tseries.offsets.BQuarterBegin.copy',
                                        'pandas.tseries.offsets.BQuarterBegin.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.is_anchored.html#pandas.tseries.offsets.BQuarterBegin.is_anchored',
                                        'pandas.tseries.offsets.BQuarterBegin.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.is_month_end.html#pandas.tseries.offsets.BQuarterBegin.is_month_end',
                                        'pandas.tseries.offsets.BQuarterBegin.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.is_month_start.html#pandas.tseries.offsets.BQuarterBegin.is_month_start',
                                        'pandas.tseries.offsets.BQuarterBegin.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.is_on_offset.html#pandas.tseries.offsets.BQuarterBegin.is_on_offset',
                                        'pandas.tseries.offsets.BQuarterBegin.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.is_quarter_end.html#pandas.tseries.offsets.BQuarterBegin.is_quarter_end',
                                        'pandas.tseries.offsets.BQuarterBegin.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.is_quarter_start.html#pandas.tseries.offsets.BQuarterBegin.is_quarter_start',
                                        'pandas.tseries.offsets.BQuarterBegin.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.is_year_end.html#pandas.tseries.offsets.BQuarterBegin.is_year_end',
                                        'pandas.tseries.offsets.BQuarterBegin.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterBegin.is_year_start.html#pandas.tseries.offsets.BQuarterBegin.is_year_start',
                                        'pandas.tseries.offsets.BQuarterEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.html#pandas.tseries.offsets.BQuarterEnd',
                                        'pandas.tseries.offsets.BQuarterEnd.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.copy.html#pandas.tseries.offsets.BQuarterEnd.copy',
                                        'pandas.tseries.offsets.BQuarterEnd.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.is_anchored.html#pandas.tseries.offsets.BQuarterEnd.is_anchored',
                                        'pandas.tseries.offsets.BQuarterEnd.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.is_month_end.html#pandas.tseries.offsets.BQuarterEnd.is_month_end',
                                        'pandas.tseries.offsets.BQuarterEnd.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.is_month_start.html#pandas.tseries.offsets.BQuarterEnd.is_month_start',
                                        'pandas.tseries.offsets.BQuarterEnd.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.is_on_offset.html#pandas.tseries.offsets.BQuarterEnd.is_on_offset',
                                        'pandas.tseries.offsets.BQuarterEnd.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.is_quarter_end.html#pandas.tseries.offsets.BQuarterEnd.is_quarter_end',
                                        'pandas.tseries.offsets.BQuarterEnd.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.is_quarter_start.html#pandas.tseries.offsets.BQuarterEnd.is_quarter_start',
                                        'pandas.tseries.offsets.BQuarterEnd.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.is_year_end.html#pandas.tseries.offsets.BQuarterEnd.is_year_end',
                                        'pandas.tseries.offsets.BQuarterEnd.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BQuarterEnd.is_year_start.html#pandas.tseries.offsets.BQuarterEnd.is_year_start',
                                        'pandas.tseries.offsets.BYearBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.html#pandas.tseries.offsets.BYearBegin',
                                        'pandas.tseries.offsets.BYearBegin.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.copy.html#pandas.tseries.offsets.BYearBegin.copy',
                                        'pandas.tseries.offsets.BYearBegin.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.is_anchored.html#pandas.tseries.offsets.BYearBegin.is_anchored',
                                        'pandas.tseries.offsets.BYearBegin.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.is_month_end.html#pandas.tseries.offsets.BYearBegin.is_month_end',
                                        'pandas.tseries.offsets.BYearBegin.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.is_month_start.html#pandas.tseries.offsets.BYearBegin.is_month_start',
                                        'pandas.tseries.offsets.BYearBegin.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.is_on_offset.html#pandas.tseries.offsets.BYearBegin.is_on_offset',
                                        'pandas.tseries.offsets.BYearBegin.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.is_quarter_end.html#pandas.tseries.offsets.BYearBegin.is_quarter_end',
                                        'pandas.tseries.offsets.BYearBegin.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.is_quarter_start.html#pandas.tseries.offsets.BYearBegin.is_quarter_start',
                                        'pandas.tseries.offsets.BYearBegin.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.is_year_end.html#pandas.tseries.offsets.BYearBegin.is_year_end',
                                        'pandas.tseries.offsets.BYearBegin.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearBegin.is_year_start.html#pandas.tseries.offsets.BYearBegin.is_year_start',
                                        'pandas.tseries.offsets.BYearEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.html#pandas.tseries.offsets.BYearEnd',
                                        'pandas.tseries.offsets.BYearEnd.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.copy.html#pandas.tseries.offsets.BYearEnd.copy',
                                        'pandas.tseries.offsets.BYearEnd.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.is_anchored.html#pandas.tseries.offsets.BYearEnd.is_anchored',
                                        'pandas.tseries.offsets.BYearEnd.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.is_month_end.html#pandas.tseries.offsets.BYearEnd.is_month_end',
                                        'pandas.tseries.offsets.BYearEnd.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.is_month_start.html#pandas.tseries.offsets.BYearEnd.is_month_start',
                                        'pandas.tseries.offsets.BYearEnd.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.is_on_offset.html#pandas.tseries.offsets.BYearEnd.is_on_offset',
                                        'pandas.tseries.offsets.BYearEnd.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.is_quarter_end.html#pandas.tseries.offsets.BYearEnd.is_quarter_end',
                                        'pandas.tseries.offsets.BYearEnd.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.is_quarter_start.html#pandas.tseries.offsets.BYearEnd.is_quarter_start',
                                        'pandas.tseries.offsets.BYearEnd.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.is_year_end.html#pandas.tseries.offsets.BYearEnd.is_year_end',
                                        'pandas.tseries.offsets.BYearEnd.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BYearEnd.is_year_start.html#pandas.tseries.offsets.BYearEnd.is_year_start',
                                        'pandas.tseries.offsets.BusinessDay': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.html#pandas.tseries.offsets.BusinessDay',
                                        'pandas.tseries.offsets.BusinessDay.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.copy.html#pandas.tseries.offsets.BusinessDay.copy',
                                        'pandas.tseries.offsets.BusinessDay.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.is_anchored.html#pandas.tseries.offsets.BusinessDay.is_anchored',
                                        'pandas.tseries.offsets.BusinessDay.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.is_month_end.html#pandas.tseries.offsets.BusinessDay.is_month_end',
                                        'pandas.tseries.offsets.BusinessDay.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.is_month_start.html#pandas.tseries.offsets.BusinessDay.is_month_start',
                                        'pandas.tseries.offsets.BusinessDay.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.is_on_offset.html#pandas.tseries.offsets.BusinessDay.is_on_offset',
                                        'pandas.tseries.offsets.BusinessDay.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.is_quarter_end.html#pandas.tseries.offsets.BusinessDay.is_quarter_end',
                                        'pandas.tseries.offsets.BusinessDay.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.is_quarter_start.html#pandas.tseries.offsets.BusinessDay.is_quarter_start',
                                        'pandas.tseries.offsets.BusinessDay.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.is_year_end.html#pandas.tseries.offsets.BusinessDay.is_year_end',
                                        'pandas.tseries.offsets.BusinessDay.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessDay.is_year_start.html#pandas.tseries.offsets.BusinessDay.is_year_start',
                                        'pandas.tseries.offsets.BusinessHour': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.html#pandas.tseries.offsets.BusinessHour',
                                        'pandas.tseries.offsets.BusinessHour.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.copy.html#pandas.tseries.offsets.BusinessHour.copy',
                                        'pandas.tseries.offsets.BusinessHour.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.is_anchored.html#pandas.tseries.offsets.BusinessHour.is_anchored',
                                        'pandas.tseries.offsets.BusinessHour.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.is_month_end.html#pandas.tseries.offsets.BusinessHour.is_month_end',
                                        'pandas.tseries.offsets.BusinessHour.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.is_month_start.html#pandas.tseries.offsets.BusinessHour.is_month_start',
                                        'pandas.tseries.offsets.BusinessHour.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.is_on_offset.html#pandas.tseries.offsets.BusinessHour.is_on_offset',
                                        'pandas.tseries.offsets.BusinessHour.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.is_quarter_end.html#pandas.tseries.offsets.BusinessHour.is_quarter_end',
                                        'pandas.tseries.offsets.BusinessHour.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.is_quarter_start.html#pandas.tseries.offsets.BusinessHour.is_quarter_start',
                                        'pandas.tseries.offsets.BusinessHour.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.is_year_end.html#pandas.tseries.offsets.BusinessHour.is_year_end',
                                        'pandas.tseries.offsets.BusinessHour.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessHour.is_year_start.html#pandas.tseries.offsets.BusinessHour.is_year_start',
                                        'pandas.tseries.offsets.BusinessMonthBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.html#pandas.tseries.offsets.BusinessMonthBegin',
                                        'pandas.tseries.offsets.BusinessMonthBegin.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.copy.html#pandas.tseries.offsets.BusinessMonthBegin.copy',
                                        'pandas.tseries.offsets.BusinessMonthBegin.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.is_anchored.html#pandas.tseries.offsets.BusinessMonthBegin.is_anchored',
                                        'pandas.tseries.offsets.BusinessMonthBegin.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.is_month_end.html#pandas.tseries.offsets.BusinessMonthBegin.is_month_end',
                                        'pandas.tseries.offsets.BusinessMonthBegin.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.is_month_start.html#pandas.tseries.offsets.BusinessMonthBegin.is_month_start',
                                        'pandas.tseries.offsets.BusinessMonthBegin.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.is_on_offset.html#pandas.tseries.offsets.BusinessMonthBegin.is_on_offset',
                                        'pandas.tseries.offsets.BusinessMonthBegin.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.is_quarter_end.html#pandas.tseries.offsets.BusinessMonthBegin.is_quarter_end',
                                        'pandas.tseries.offsets.BusinessMonthBegin.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.is_quarter_start.html#pandas.tseries.offsets.BusinessMonthBegin.is_quarter_start',
                                        'pandas.tseries.offsets.BusinessMonthBegin.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.is_year_end.html#pandas.tseries.offsets.BusinessMonthBegin.is_year_end',
                                        'pandas.tseries.offsets.BusinessMonthBegin.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthBegin.is_year_start.html#pandas.tseries.offsets.BusinessMonthBegin.is_year_start',
                                        'pandas.tseries.offsets.BusinessMonthEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.html#pandas.tseries.offsets.BusinessMonthEnd',
                                        'pandas.tseries.offsets.BusinessMonthEnd.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.copy.html#pandas.tseries.offsets.BusinessMonthEnd.copy',
                                        'pandas.tseries.offsets.BusinessMonthEnd.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.is_anchored.html#pandas.tseries.offsets.BusinessMonthEnd.is_anchored',
                                        'pandas.tseries.offsets.BusinessMonthEnd.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.is_month_end.html#pandas.tseries.offsets.BusinessMonthEnd.is_month_end',
                                        'pandas.tseries.offsets.BusinessMonthEnd.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.is_month_start.html#pandas.tseries.offsets.BusinessMonthEnd.is_month_start',
                                        'pandas.tseries.offsets.BusinessMonthEnd.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.is_on_offset.html#pandas.tseries.offsets.BusinessMonthEnd.is_on_offset',
                                        'pandas.tseries.offsets.BusinessMonthEnd.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.is_quarter_end.html#pandas.tseries.offsets.BusinessMonthEnd.is_quarter_end',
                                        'pandas.tseries.offsets.BusinessMonthEnd.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.is_quarter_start.html#pandas.tseries.offsets.BusinessMonthEnd.is_quarter_start',
                                        'pandas.tseries.offsets.BusinessMonthEnd.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.is_year_end.html#pandas.tseries.offsets.BusinessMonthEnd.is_year_end',
                                        'pandas.tseries.offsets.BusinessMonthEnd.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.BusinessMonthEnd.is_year_start.html#pandas.tseries.offsets.BusinessMonthEnd.is_year_start',
                                        'pandas.tseries.offsets.CustomBusinessDay': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.html#pandas.tseries.offsets.CustomBusinessDay',
                                        'pandas.tseries.offsets.CustomBusinessDay.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.copy.html#pandas.tseries.offsets.CustomBusinessDay.copy',
                                        'pandas.tseries.offsets.CustomBusinessDay.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.is_anchored.html#pandas.tseries.offsets.CustomBusinessDay.is_anchored',
                                        'pandas.tseries.offsets.CustomBusinessDay.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.is_month_end.html#pandas.tseries.offsets.CustomBusinessDay.is_month_end',
                                        'pandas.tseries.offsets.CustomBusinessDay.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.is_month_start.html#pandas.tseries.offsets.CustomBusinessDay.is_month_start',
                                        'pandas.tseries.offsets.CustomBusinessDay.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.is_on_offset.html#pandas.tseries.offsets.CustomBusinessDay.is_on_offset',
                                        'pandas.tseries.offsets.CustomBusinessDay.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.is_quarter_end.html#pandas.tseries.offsets.CustomBusinessDay.is_quarter_end',
                                        'pandas.tseries.offsets.CustomBusinessDay.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.is_quarter_start.html#pandas.tseries.offsets.CustomBusinessDay.is_quarter_start',
                                        'pandas.tseries.offsets.CustomBusinessDay.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.is_year_end.html#pandas.tseries.offsets.CustomBusinessDay.is_year_end',
                                        'pandas.tseries.offsets.CustomBusinessDay.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessDay.is_year_start.html#pandas.tseries.offsets.CustomBusinessDay.is_year_start',
                                        'pandas.tseries.offsets.CustomBusinessHour': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.html#pandas.tseries.offsets.CustomBusinessHour',
                                        'pandas.tseries.offsets.CustomBusinessHour.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.copy.html#pandas.tseries.offsets.CustomBusinessHour.copy',
                                        'pandas.tseries.offsets.CustomBusinessHour.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.is_anchored.html#pandas.tseries.offsets.CustomBusinessHour.is_anchored',
                                        'pandas.tseries.offsets.CustomBusinessHour.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.is_month_end.html#pandas.tseries.offsets.CustomBusinessHour.is_month_end',
                                        'pandas.tseries.offsets.CustomBusinessHour.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.is_month_start.html#pandas.tseries.offsets.CustomBusinessHour.is_month_start',
                                        'pandas.tseries.offsets.CustomBusinessHour.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.is_on_offset.html#pandas.tseries.offsets.CustomBusinessHour.is_on_offset',
                                        'pandas.tseries.offsets.CustomBusinessHour.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.is_quarter_end.html#pandas.tseries.offsets.CustomBusinessHour.is_quarter_end',
                                        'pandas.tseries.offsets.CustomBusinessHour.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.is_quarter_start.html#pandas.tseries.offsets.CustomBusinessHour.is_quarter_start',
                                        'pandas.tseries.offsets.CustomBusinessHour.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.is_year_end.html#pandas.tseries.offsets.CustomBusinessHour.is_year_end',
                                        'pandas.tseries.offsets.CustomBusinessHour.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessHour.is_year_start.html#pandas.tseries.offsets.CustomBusinessHour.is_year_start',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.html#pandas.tseries.offsets.CustomBusinessMonthBegin',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.copy.html#pandas.tseries.offsets.CustomBusinessMonthBegin.copy',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.is_anchored.html#pandas.tseries.offsets.CustomBusinessMonthBegin.is_anchored',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.is_month_end.html#pandas.tseries.offsets.CustomBusinessMonthBegin.is_month_end',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.is_month_start.html#pandas.tseries.offsets.CustomBusinessMonthBegin.is_month_start',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.is_on_offset.html#pandas.tseries.offsets.CustomBusinessMonthBegin.is_on_offset',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.is_quarter_end.html#pandas.tseries.offsets.CustomBusinessMonthBegin.is_quarter_end',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.is_quarter_start.html#pandas.tseries.offsets.CustomBusinessMonthBegin.is_quarter_start',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.is_year_end.html#pandas.tseries.offsets.CustomBusinessMonthBegin.is_year_end',
                                        'pandas.tseries.offsets.CustomBusinessMonthBegin.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthBegin.is_year_start.html#pandas.tseries.offsets.CustomBusinessMonthBegin.is_year_start',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.html#pandas.tseries.offsets.CustomBusinessMonthEnd',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.copy.html#pandas.tseries.offsets.CustomBusinessMonthEnd.copy',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.is_anchored.html#pandas.tseries.offsets.CustomBusinessMonthEnd.is_anchored',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.is_month_end.html#pandas.tseries.offsets.CustomBusinessMonthEnd.is_month_end',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.is_month_start.html#pandas.tseries.offsets.CustomBusinessMonthEnd.is_month_start',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.is_on_offset.html#pandas.tseries.offsets.CustomBusinessMonthEnd.is_on_offset',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.is_quarter_end.html#pandas.tseries.offsets.CustomBusinessMonthEnd.is_quarter_end',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.is_quarter_start.html#pandas.tseries.offsets.CustomBusinessMonthEnd.is_quarter_start',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.is_year_end.html#pandas.tseries.offsets.CustomBusinessMonthEnd.is_year_end',
                                        'pandas.tseries.offsets.CustomBusinessMonthEnd.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.CustomBusinessMonthEnd.is_year_start.html#pandas.tseries.offsets.CustomBusinessMonthEnd.is_year_start',
                                        'pandas.tseries.offsets.DateOffset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.html#pandas.tseries.offsets.DateOffset',
                                        'pandas.tseries.offsets.DateOffset.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.copy.html#pandas.tseries.offsets.DateOffset.copy',
                                        'pandas.tseries.offsets.DateOffset.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.is_anchored.html#pandas.tseries.offsets.DateOffset.is_anchored',
                                        'pandas.tseries.offsets.DateOffset.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.is_month_end.html#pandas.tseries.offsets.DateOffset.is_month_end',
                                        'pandas.tseries.offsets.DateOffset.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.is_month_start.html#pandas.tseries.offsets.DateOffset.is_month_start',
                                        'pandas.tseries.offsets.DateOffset.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.is_on_offset.html#pandas.tseries.offsets.DateOffset.is_on_offset',
                                        'pandas.tseries.offsets.DateOffset.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.is_quarter_end.html#pandas.tseries.offsets.DateOffset.is_quarter_end',
                                        'pandas.tseries.offsets.DateOffset.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.is_quarter_start.html#pandas.tseries.offsets.DateOffset.is_quarter_start',
                                        'pandas.tseries.offsets.DateOffset.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.is_year_end.html#pandas.tseries.offsets.DateOffset.is_year_end',
                                        'pandas.tseries.offsets.DateOffset.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.DateOffset.is_year_start.html#pandas.tseries.offsets.DateOffset.is_year_start',
                                        'pandas.tseries.offsets.Day': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.html#pandas.tseries.offsets.Day',
                                        'pandas.tseries.offsets.Day.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.copy.html#pandas.tseries.offsets.Day.copy',
                                        'pandas.tseries.offsets.Day.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.is_anchored.html#pandas.tseries.offsets.Day.is_anchored',
                                        'pandas.tseries.offsets.Day.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.is_month_end.html#pandas.tseries.offsets.Day.is_month_end',
                                        'pandas.tseries.offsets.Day.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.is_month_start.html#pandas.tseries.offsets.Day.is_month_start',
                                        'pandas.tseries.offsets.Day.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.is_on_offset.html#pandas.tseries.offsets.Day.is_on_offset',
                                        'pandas.tseries.offsets.Day.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.is_quarter_end.html#pandas.tseries.offsets.Day.is_quarter_end',
                                        'pandas.tseries.offsets.Day.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.is_quarter_start.html#pandas.tseries.offsets.Day.is_quarter_start',
                                        'pandas.tseries.offsets.Day.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.is_year_end.html#pandas.tseries.offsets.Day.is_year_end',
                                        'pandas.tseries.offsets.Day.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Day.is_year_start.html#pandas.tseries.offsets.Day.is_year_start',
                                        'pandas.tseries.offsets.Easter': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.html#pandas.tseries.offsets.Easter',
                                        'pandas.tseries.offsets.Easter.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.copy.html#pandas.tseries.offsets.Easter.copy',
                                        'pandas.tseries.offsets.Easter.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.is_anchored.html#pandas.tseries.offsets.Easter.is_anchored',
                                        'pandas.tseries.offsets.Easter.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.is_month_end.html#pandas.tseries.offsets.Easter.is_month_end',
                                        'pandas.tseries.offsets.Easter.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.is_month_start.html#pandas.tseries.offsets.Easter.is_month_start',
                                        'pandas.tseries.offsets.Easter.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.is_on_offset.html#pandas.tseries.offsets.Easter.is_on_offset',
                                        'pandas.tseries.offsets.Easter.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.is_quarter_end.html#pandas.tseries.offsets.Easter.is_quarter_end',
                                        'pandas.tseries.offsets.Easter.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.is_quarter_start.html#pandas.tseries.offsets.Easter.is_quarter_start',
                                        'pandas.tseries.offsets.Easter.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.is_year_end.html#pandas.tseries.offsets.Easter.is_year_end',
                                        'pandas.tseries.offsets.Easter.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Easter.is_year_start.html#pandas.tseries.offsets.Easter.is_year_start',
                                        'pandas.tseries.offsets.FY5253': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.html#pandas.tseries.offsets.FY5253',
                                        'pandas.tseries.offsets.FY5253.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.copy.html#pandas.tseries.offsets.FY5253.copy',
                                        'pandas.tseries.offsets.FY5253.get_rule_code_suffix': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.get_rule_code_suffix.html#pandas.tseries.offsets.FY5253.get_rule_code_suffix',
                                        'pandas.tseries.offsets.FY5253.get_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.get_year_end.html#pandas.tseries.offsets.FY5253.get_year_end',
                                        'pandas.tseries.offsets.FY5253.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.is_anchored.html#pandas.tseries.offsets.FY5253.is_anchored',
                                        'pandas.tseries.offsets.FY5253.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.is_month_end.html#pandas.tseries.offsets.FY5253.is_month_end',
                                        'pandas.tseries.offsets.FY5253.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.is_month_start.html#pandas.tseries.offsets.FY5253.is_month_start',
                                        'pandas.tseries.offsets.FY5253.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.is_on_offset.html#pandas.tseries.offsets.FY5253.is_on_offset',
                                        'pandas.tseries.offsets.FY5253.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.is_quarter_end.html#pandas.tseries.offsets.FY5253.is_quarter_end',
                                        'pandas.tseries.offsets.FY5253.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.is_quarter_start.html#pandas.tseries.offsets.FY5253.is_quarter_start',
                                        'pandas.tseries.offsets.FY5253.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.is_year_end.html#pandas.tseries.offsets.FY5253.is_year_end',
                                        'pandas.tseries.offsets.FY5253.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253.is_year_start.html#pandas.tseries.offsets.FY5253.is_year_start',
                                        'pandas.tseries.offsets.FY5253Quarter': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.html#pandas.tseries.offsets.FY5253Quarter',
                                        'pandas.tseries.offsets.FY5253Quarter.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.copy.html#pandas.tseries.offsets.FY5253Quarter.copy',
                                        'pandas.tseries.offsets.FY5253Quarter.get_rule_code_suffix': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.get_rule_code_suffix.html#pandas.tseries.offsets.FY5253Quarter.get_rule_code_suffix',
                                        'pandas.tseries.offsets.FY5253Quarter.get_weeks': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.get_weeks.html#pandas.tseries.offsets.FY5253Quarter.get_weeks',
                                        'pandas.tseries.offsets.FY5253Quarter.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.is_anchored.html#pandas.tseries.offsets.FY5253Quarter.is_anchored',
                                        'pandas.tseries.offsets.FY5253Quarter.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.is_month_end.html#pandas.tseries.offsets.FY5253Quarter.is_month_end',
                                        'pandas.tseries.offsets.FY5253Quarter.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.is_month_start.html#pandas.tseries.offsets.FY5253Quarter.is_month_start',
                                        'pandas.tseries.offsets.FY5253Quarter.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.is_on_offset.html#pandas.tseries.offsets.FY5253Quarter.is_on_offset',
                                        'pandas.tseries.offsets.FY5253Quarter.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.is_quarter_end.html#pandas.tseries.offsets.FY5253Quarter.is_quarter_end',
                                        'pandas.tseries.offsets.FY5253Quarter.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.is_quarter_start.html#pandas.tseries.offsets.FY5253Quarter.is_quarter_start',
                                        'pandas.tseries.offsets.FY5253Quarter.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.is_year_end.html#pandas.tseries.offsets.FY5253Quarter.is_year_end',
                                        'pandas.tseries.offsets.FY5253Quarter.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.is_year_start.html#pandas.tseries.offsets.FY5253Quarter.is_year_start',
                                        'pandas.tseries.offsets.FY5253Quarter.year_has_extra_week': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.FY5253Quarter.year_has_extra_week.html#pandas.tseries.offsets.FY5253Quarter.year_has_extra_week',
                                        'pandas.tseries.offsets.Hour': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.html#pandas.tseries.offsets.Hour',
                                        'pandas.tseries.offsets.Hour.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.copy.html#pandas.tseries.offsets.Hour.copy',
                                        'pandas.tseries.offsets.Hour.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.is_anchored.html#pandas.tseries.offsets.Hour.is_anchored',
                                        'pandas.tseries.offsets.Hour.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.is_month_end.html#pandas.tseries.offsets.Hour.is_month_end',
                                        'pandas.tseries.offsets.Hour.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.is_month_start.html#pandas.tseries.offsets.Hour.is_month_start',
                                        'pandas.tseries.offsets.Hour.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.is_on_offset.html#pandas.tseries.offsets.Hour.is_on_offset',
                                        'pandas.tseries.offsets.Hour.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.is_quarter_end.html#pandas.tseries.offsets.Hour.is_quarter_end',
                                        'pandas.tseries.offsets.Hour.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.is_quarter_start.html#pandas.tseries.offsets.Hour.is_quarter_start',
                                        'pandas.tseries.offsets.Hour.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.is_year_end.html#pandas.tseries.offsets.Hour.is_year_end',
                                        'pandas.tseries.offsets.Hour.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Hour.is_year_start.html#pandas.tseries.offsets.Hour.is_year_start',
                                        'pandas.tseries.offsets.LastWeekOfMonth': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.html#pandas.tseries.offsets.LastWeekOfMonth',
                                        'pandas.tseries.offsets.LastWeekOfMonth.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.copy.html#pandas.tseries.offsets.LastWeekOfMonth.copy',
                                        'pandas.tseries.offsets.LastWeekOfMonth.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.is_anchored.html#pandas.tseries.offsets.LastWeekOfMonth.is_anchored',
                                        'pandas.tseries.offsets.LastWeekOfMonth.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.is_month_end.html#pandas.tseries.offsets.LastWeekOfMonth.is_month_end',
                                        'pandas.tseries.offsets.LastWeekOfMonth.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.is_month_start.html#pandas.tseries.offsets.LastWeekOfMonth.is_month_start',
                                        'pandas.tseries.offsets.LastWeekOfMonth.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.is_on_offset.html#pandas.tseries.offsets.LastWeekOfMonth.is_on_offset',
                                        'pandas.tseries.offsets.LastWeekOfMonth.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.is_quarter_end.html#pandas.tseries.offsets.LastWeekOfMonth.is_quarter_end',
                                        'pandas.tseries.offsets.LastWeekOfMonth.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.is_quarter_start.html#pandas.tseries.offsets.LastWeekOfMonth.is_quarter_start',
                                        'pandas.tseries.offsets.LastWeekOfMonth.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.is_year_end.html#pandas.tseries.offsets.LastWeekOfMonth.is_year_end',
                                        'pandas.tseries.offsets.LastWeekOfMonth.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.LastWeekOfMonth.is_year_start.html#pandas.tseries.offsets.LastWeekOfMonth.is_year_start',
                                        'pandas.tseries.offsets.Micro': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.html#pandas.tseries.offsets.Micro',
                                        'pandas.tseries.offsets.Micro.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.copy.html#pandas.tseries.offsets.Micro.copy',
                                        'pandas.tseries.offsets.Micro.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.is_anchored.html#pandas.tseries.offsets.Micro.is_anchored',
                                        'pandas.tseries.offsets.Micro.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.is_month_end.html#pandas.tseries.offsets.Micro.is_month_end',
                                        'pandas.tseries.offsets.Micro.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.is_month_start.html#pandas.tseries.offsets.Micro.is_month_start',
                                        'pandas.tseries.offsets.Micro.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.is_on_offset.html#pandas.tseries.offsets.Micro.is_on_offset',
                                        'pandas.tseries.offsets.Micro.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.is_quarter_end.html#pandas.tseries.offsets.Micro.is_quarter_end',
                                        'pandas.tseries.offsets.Micro.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.is_quarter_start.html#pandas.tseries.offsets.Micro.is_quarter_start',
                                        'pandas.tseries.offsets.Micro.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.is_year_end.html#pandas.tseries.offsets.Micro.is_year_end',
                                        'pandas.tseries.offsets.Micro.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Micro.is_year_start.html#pandas.tseries.offsets.Micro.is_year_start',
                                        'pandas.tseries.offsets.Milli': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.html#pandas.tseries.offsets.Milli',
                                        'pandas.tseries.offsets.Milli.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.copy.html#pandas.tseries.offsets.Milli.copy',
                                        'pandas.tseries.offsets.Milli.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.is_anchored.html#pandas.tseries.offsets.Milli.is_anchored',
                                        'pandas.tseries.offsets.Milli.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.is_month_end.html#pandas.tseries.offsets.Milli.is_month_end',
                                        'pandas.tseries.offsets.Milli.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.is_month_start.html#pandas.tseries.offsets.Milli.is_month_start',
                                        'pandas.tseries.offsets.Milli.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.is_on_offset.html#pandas.tseries.offsets.Milli.is_on_offset',
                                        'pandas.tseries.offsets.Milli.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.is_quarter_end.html#pandas.tseries.offsets.Milli.is_quarter_end',
                                        'pandas.tseries.offsets.Milli.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.is_quarter_start.html#pandas.tseries.offsets.Milli.is_quarter_start',
                                        'pandas.tseries.offsets.Milli.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.is_year_end.html#pandas.tseries.offsets.Milli.is_year_end',
                                        'pandas.tseries.offsets.Milli.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Milli.is_year_start.html#pandas.tseries.offsets.Milli.is_year_start',
                                        'pandas.tseries.offsets.Minute': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.html#pandas.tseries.offsets.Minute',
                                        'pandas.tseries.offsets.Minute.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.copy.html#pandas.tseries.offsets.Minute.copy',
                                        'pandas.tseries.offsets.Minute.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.is_anchored.html#pandas.tseries.offsets.Minute.is_anchored',
                                        'pandas.tseries.offsets.Minute.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.is_month_end.html#pandas.tseries.offsets.Minute.is_month_end',
                                        'pandas.tseries.offsets.Minute.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.is_month_start.html#pandas.tseries.offsets.Minute.is_month_start',
                                        'pandas.tseries.offsets.Minute.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.is_on_offset.html#pandas.tseries.offsets.Minute.is_on_offset',
                                        'pandas.tseries.offsets.Minute.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.is_quarter_end.html#pandas.tseries.offsets.Minute.is_quarter_end',
                                        'pandas.tseries.offsets.Minute.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.is_quarter_start.html#pandas.tseries.offsets.Minute.is_quarter_start',
                                        'pandas.tseries.offsets.Minute.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.is_year_end.html#pandas.tseries.offsets.Minute.is_year_end',
                                        'pandas.tseries.offsets.Minute.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Minute.is_year_start.html#pandas.tseries.offsets.Minute.is_year_start',
                                        'pandas.tseries.offsets.MonthBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.html#pandas.tseries.offsets.MonthBegin',
                                        'pandas.tseries.offsets.MonthBegin.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.copy.html#pandas.tseries.offsets.MonthBegin.copy',
                                        'pandas.tseries.offsets.MonthBegin.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.is_anchored.html#pandas.tseries.offsets.MonthBegin.is_anchored',
                                        'pandas.tseries.offsets.MonthBegin.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.is_month_end.html#pandas.tseries.offsets.MonthBegin.is_month_end',
                                        'pandas.tseries.offsets.MonthBegin.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.is_month_start.html#pandas.tseries.offsets.MonthBegin.is_month_start',
                                        'pandas.tseries.offsets.MonthBegin.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.is_on_offset.html#pandas.tseries.offsets.MonthBegin.is_on_offset',
                                        'pandas.tseries.offsets.MonthBegin.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.is_quarter_end.html#pandas.tseries.offsets.MonthBegin.is_quarter_end',
                                        'pandas.tseries.offsets.MonthBegin.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.is_quarter_start.html#pandas.tseries.offsets.MonthBegin.is_quarter_start',
                                        'pandas.tseries.offsets.MonthBegin.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.is_year_end.html#pandas.tseries.offsets.MonthBegin.is_year_end',
                                        'pandas.tseries.offsets.MonthBegin.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthBegin.is_year_start.html#pandas.tseries.offsets.MonthBegin.is_year_start',
                                        'pandas.tseries.offsets.MonthEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.html#pandas.tseries.offsets.MonthEnd',
                                        'pandas.tseries.offsets.MonthEnd.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.copy.html#pandas.tseries.offsets.MonthEnd.copy',
                                        'pandas.tseries.offsets.MonthEnd.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.is_anchored.html#pandas.tseries.offsets.MonthEnd.is_anchored',
                                        'pandas.tseries.offsets.MonthEnd.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.is_month_end.html#pandas.tseries.offsets.MonthEnd.is_month_end',
                                        'pandas.tseries.offsets.MonthEnd.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.is_month_start.html#pandas.tseries.offsets.MonthEnd.is_month_start',
                                        'pandas.tseries.offsets.MonthEnd.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.is_on_offset.html#pandas.tseries.offsets.MonthEnd.is_on_offset',
                                        'pandas.tseries.offsets.MonthEnd.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.is_quarter_end.html#pandas.tseries.offsets.MonthEnd.is_quarter_end',
                                        'pandas.tseries.offsets.MonthEnd.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.is_quarter_start.html#pandas.tseries.offsets.MonthEnd.is_quarter_start',
                                        'pandas.tseries.offsets.MonthEnd.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.is_year_end.html#pandas.tseries.offsets.MonthEnd.is_year_end',
                                        'pandas.tseries.offsets.MonthEnd.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.MonthEnd.is_year_start.html#pandas.tseries.offsets.MonthEnd.is_year_start',
                                        'pandas.tseries.offsets.Nano': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.html#pandas.tseries.offsets.Nano',
                                        'pandas.tseries.offsets.Nano.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.copy.html#pandas.tseries.offsets.Nano.copy',
                                        'pandas.tseries.offsets.Nano.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.is_anchored.html#pandas.tseries.offsets.Nano.is_anchored',
                                        'pandas.tseries.offsets.Nano.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.is_month_end.html#pandas.tseries.offsets.Nano.is_month_end',
                                        'pandas.tseries.offsets.Nano.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.is_month_start.html#pandas.tseries.offsets.Nano.is_month_start',
                                        'pandas.tseries.offsets.Nano.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.is_on_offset.html#pandas.tseries.offsets.Nano.is_on_offset',
                                        'pandas.tseries.offsets.Nano.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.is_quarter_end.html#pandas.tseries.offsets.Nano.is_quarter_end',
                                        'pandas.tseries.offsets.Nano.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.is_quarter_start.html#pandas.tseries.offsets.Nano.is_quarter_start',
                                        'pandas.tseries.offsets.Nano.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.is_year_end.html#pandas.tseries.offsets.Nano.is_year_end',
                                        'pandas.tseries.offsets.Nano.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Nano.is_year_start.html#pandas.tseries.offsets.Nano.is_year_start',
                                        'pandas.tseries.offsets.QuarterBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.html#pandas.tseries.offsets.QuarterBegin',
                                        'pandas.tseries.offsets.QuarterBegin.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.copy.html#pandas.tseries.offsets.QuarterBegin.copy',
                                        'pandas.tseries.offsets.QuarterBegin.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.is_anchored.html#pandas.tseries.offsets.QuarterBegin.is_anchored',
                                        'pandas.tseries.offsets.QuarterBegin.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.is_month_end.html#pandas.tseries.offsets.QuarterBegin.is_month_end',
                                        'pandas.tseries.offsets.QuarterBegin.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.is_month_start.html#pandas.tseries.offsets.QuarterBegin.is_month_start',
                                        'pandas.tseries.offsets.QuarterBegin.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.is_on_offset.html#pandas.tseries.offsets.QuarterBegin.is_on_offset',
                                        'pandas.tseries.offsets.QuarterBegin.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.is_quarter_end.html#pandas.tseries.offsets.QuarterBegin.is_quarter_end',
                                        'pandas.tseries.offsets.QuarterBegin.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.is_quarter_start.html#pandas.tseries.offsets.QuarterBegin.is_quarter_start',
                                        'pandas.tseries.offsets.QuarterBegin.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.is_year_end.html#pandas.tseries.offsets.QuarterBegin.is_year_end',
                                        'pandas.tseries.offsets.QuarterBegin.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterBegin.is_year_start.html#pandas.tseries.offsets.QuarterBegin.is_year_start',
                                        'pandas.tseries.offsets.QuarterEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.html#pandas.tseries.offsets.QuarterEnd',
                                        'pandas.tseries.offsets.QuarterEnd.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.copy.html#pandas.tseries.offsets.QuarterEnd.copy',
                                        'pandas.tseries.offsets.QuarterEnd.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.is_anchored.html#pandas.tseries.offsets.QuarterEnd.is_anchored',
                                        'pandas.tseries.offsets.QuarterEnd.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.is_month_end.html#pandas.tseries.offsets.QuarterEnd.is_month_end',
                                        'pandas.tseries.offsets.QuarterEnd.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.is_month_start.html#pandas.tseries.offsets.QuarterEnd.is_month_start',
                                        'pandas.tseries.offsets.QuarterEnd.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.is_on_offset.html#pandas.tseries.offsets.QuarterEnd.is_on_offset',
                                        'pandas.tseries.offsets.QuarterEnd.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.is_quarter_end.html#pandas.tseries.offsets.QuarterEnd.is_quarter_end',
                                        'pandas.tseries.offsets.QuarterEnd.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.is_quarter_start.html#pandas.tseries.offsets.QuarterEnd.is_quarter_start',
                                        'pandas.tseries.offsets.QuarterEnd.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.is_year_end.html#pandas.tseries.offsets.QuarterEnd.is_year_end',
                                        'pandas.tseries.offsets.QuarterEnd.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.QuarterEnd.is_year_start.html#pandas.tseries.offsets.QuarterEnd.is_year_start',
                                        'pandas.tseries.offsets.Second': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.html#pandas.tseries.offsets.Second',
                                        'pandas.tseries.offsets.Second.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.copy.html#pandas.tseries.offsets.Second.copy',
                                        'pandas.tseries.offsets.Second.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.is_anchored.html#pandas.tseries.offsets.Second.is_anchored',
                                        'pandas.tseries.offsets.Second.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.is_month_end.html#pandas.tseries.offsets.Second.is_month_end',
                                        'pandas.tseries.offsets.Second.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.is_month_start.html#pandas.tseries.offsets.Second.is_month_start',
                                        'pandas.tseries.offsets.Second.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.is_on_offset.html#pandas.tseries.offsets.Second.is_on_offset',
                                        'pandas.tseries.offsets.Second.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.is_quarter_end.html#pandas.tseries.offsets.Second.is_quarter_end',
                                        'pandas.tseries.offsets.Second.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.is_quarter_start.html#pandas.tseries.offsets.Second.is_quarter_start',
                                        'pandas.tseries.offsets.Second.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.is_year_end.html#pandas.tseries.offsets.Second.is_year_end',
                                        'pandas.tseries.offsets.Second.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Second.is_year_start.html#pandas.tseries.offsets.Second.is_year_start',
                                        'pandas.tseries.offsets.SemiMonthBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.html#pandas.tseries.offsets.SemiMonthBegin',
                                        'pandas.tseries.offsets.SemiMonthBegin.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.copy.html#pandas.tseries.offsets.SemiMonthBegin.copy',
                                        'pandas.tseries.offsets.SemiMonthBegin.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.is_anchored.html#pandas.tseries.offsets.SemiMonthBegin.is_anchored',
                                        'pandas.tseries.offsets.SemiMonthBegin.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.is_month_end.html#pandas.tseries.offsets.SemiMonthBegin.is_month_end',
                                        'pandas.tseries.offsets.SemiMonthBegin.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.is_month_start.html#pandas.tseries.offsets.SemiMonthBegin.is_month_start',
                                        'pandas.tseries.offsets.SemiMonthBegin.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.is_on_offset.html#pandas.tseries.offsets.SemiMonthBegin.is_on_offset',
                                        'pandas.tseries.offsets.SemiMonthBegin.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.is_quarter_end.html#pandas.tseries.offsets.SemiMonthBegin.is_quarter_end',
                                        'pandas.tseries.offsets.SemiMonthBegin.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.is_quarter_start.html#pandas.tseries.offsets.SemiMonthBegin.is_quarter_start',
                                        'pandas.tseries.offsets.SemiMonthBegin.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.is_year_end.html#pandas.tseries.offsets.SemiMonthBegin.is_year_end',
                                        'pandas.tseries.offsets.SemiMonthBegin.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthBegin.is_year_start.html#pandas.tseries.offsets.SemiMonthBegin.is_year_start',
                                        'pandas.tseries.offsets.SemiMonthEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.html#pandas.tseries.offsets.SemiMonthEnd',
                                        'pandas.tseries.offsets.SemiMonthEnd.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.copy.html#pandas.tseries.offsets.SemiMonthEnd.copy',
                                        'pandas.tseries.offsets.SemiMonthEnd.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.is_anchored.html#pandas.tseries.offsets.SemiMonthEnd.is_anchored',
                                        'pandas.tseries.offsets.SemiMonthEnd.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.is_month_end.html#pandas.tseries.offsets.SemiMonthEnd.is_month_end',
                                        'pandas.tseries.offsets.SemiMonthEnd.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.is_month_start.html#pandas.tseries.offsets.SemiMonthEnd.is_month_start',
                                        'pandas.tseries.offsets.SemiMonthEnd.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.is_on_offset.html#pandas.tseries.offsets.SemiMonthEnd.is_on_offset',
                                        'pandas.tseries.offsets.SemiMonthEnd.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.is_quarter_end.html#pandas.tseries.offsets.SemiMonthEnd.is_quarter_end',
                                        'pandas.tseries.offsets.SemiMonthEnd.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.is_quarter_start.html#pandas.tseries.offsets.SemiMonthEnd.is_quarter_start',
                                        'pandas.tseries.offsets.SemiMonthEnd.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.is_year_end.html#pandas.tseries.offsets.SemiMonthEnd.is_year_end',
                                        'pandas.tseries.offsets.SemiMonthEnd.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.SemiMonthEnd.is_year_start.html#pandas.tseries.offsets.SemiMonthEnd.is_year_start',
                                        'pandas.tseries.offsets.Tick': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.html#pandas.tseries.offsets.Tick',
                                        'pandas.tseries.offsets.Tick.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.copy.html#pandas.tseries.offsets.Tick.copy',
                                        'pandas.tseries.offsets.Tick.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.is_anchored.html#pandas.tseries.offsets.Tick.is_anchored',
                                        'pandas.tseries.offsets.Tick.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.is_month_end.html#pandas.tseries.offsets.Tick.is_month_end',
                                        'pandas.tseries.offsets.Tick.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.is_month_start.html#pandas.tseries.offsets.Tick.is_month_start',
                                        'pandas.tseries.offsets.Tick.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.is_on_offset.html#pandas.tseries.offsets.Tick.is_on_offset',
                                        'pandas.tseries.offsets.Tick.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.is_quarter_end.html#pandas.tseries.offsets.Tick.is_quarter_end',
                                        'pandas.tseries.offsets.Tick.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.is_quarter_start.html#pandas.tseries.offsets.Tick.is_quarter_start',
                                        'pandas.tseries.offsets.Tick.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.is_year_end.html#pandas.tseries.offsets.Tick.is_year_end',
                                        'pandas.tseries.offsets.Tick.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Tick.is_year_start.html#pandas.tseries.offsets.Tick.is_year_start',
                                        'pandas.tseries.offsets.Week': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.html#pandas.tseries.offsets.Week',
                                        'pandas.tseries.offsets.Week.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.copy.html#pandas.tseries.offsets.Week.copy',
                                        'pandas.tseries.offsets.Week.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.is_anchored.html#pandas.tseries.offsets.Week.is_anchored',
                                        'pandas.tseries.offsets.Week.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.is_month_end.html#pandas.tseries.offsets.Week.is_month_end',
                                        'pandas.tseries.offsets.Week.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.is_month_start.html#pandas.tseries.offsets.Week.is_month_start',
                                        'pandas.tseries.offsets.Week.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.is_on_offset.html#pandas.tseries.offsets.Week.is_on_offset',
                                        'pandas.tseries.offsets.Week.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.is_quarter_end.html#pandas.tseries.offsets.Week.is_quarter_end',
                                        'pandas.tseries.offsets.Week.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.is_quarter_start.html#pandas.tseries.offsets.Week.is_quarter_start',
                                        'pandas.tseries.offsets.Week.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.is_year_end.html#pandas.tseries.offsets.Week.is_year_end',
                                        'pandas.tseries.offsets.Week.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.Week.is_year_start.html#pandas.tseries.offsets.Week.is_year_start',
                                        'pandas.tseries.offsets.WeekOfMonth': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.html#pandas.tseries.offsets.WeekOfMonth',
                                        'pandas.tseries.offsets.WeekOfMonth.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.copy.html#pandas.tseries.offsets.WeekOfMonth.copy',
                                        'pandas.tseries.offsets.WeekOfMonth.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.is_anchored.html#pandas.tseries.offsets.WeekOfMonth.is_anchored',
                                        'pandas.tseries.offsets.WeekOfMonth.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.is_month_end.html#pandas.tseries.offsets.WeekOfMonth.is_month_end',
                                        'pandas.tseries.offsets.WeekOfMonth.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.is_month_start.html#pandas.tseries.offsets.WeekOfMonth.is_month_start',
                                        'pandas.tseries.offsets.WeekOfMonth.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.is_on_offset.html#pandas.tseries.offsets.WeekOfMonth.is_on_offset',
                                        'pandas.tseries.offsets.WeekOfMonth.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.is_quarter_end.html#pandas.tseries.offsets.WeekOfMonth.is_quarter_end',
                                        'pandas.tseries.offsets.WeekOfMonth.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.is_quarter_start.html#pandas.tseries.offsets.WeekOfMonth.is_quarter_start',
                                        'pandas.tseries.offsets.WeekOfMonth.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.is_year_end.html#pandas.tseries.offsets.WeekOfMonth.is_year_end',
                                        'pandas.tseries.offsets.WeekOfMonth.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.WeekOfMonth.is_year_start.html#pandas.tseries.offsets.WeekOfMonth.is_year_start',
                                        'pandas.tseries.offsets.YearBegin': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.html#pandas.tseries.offsets.YearBegin',
                                        'pandas.tseries.offsets.YearBegin.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.copy.html#pandas.tseries.offsets.YearBegin.copy',
                                        'pandas.tseries.offsets.YearBegin.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.is_anchored.html#pandas.tseries.offsets.YearBegin.is_anchored',
                                        'pandas.tseries.offsets.YearBegin.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.is_month_end.html#pandas.tseries.offsets.YearBegin.is_month_end',
                                        'pandas.tseries.offsets.YearBegin.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.is_month_start.html#pandas.tseries.offsets.YearBegin.is_month_start',
                                        'pandas.tseries.offsets.YearBegin.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.is_on_offset.html#pandas.tseries.offsets.YearBegin.is_on_offset',
                                        'pandas.tseries.offsets.YearBegin.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.is_quarter_end.html#pandas.tseries.offsets.YearBegin.is_quarter_end',
                                        'pandas.tseries.offsets.YearBegin.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.is_quarter_start.html#pandas.tseries.offsets.YearBegin.is_quarter_start',
                                        'pandas.tseries.offsets.YearBegin.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.is_year_end.html#pandas.tseries.offsets.YearBegin.is_year_end',
                                        'pandas.tseries.offsets.YearBegin.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearBegin.is_year_start.html#pandas.tseries.offsets.YearBegin.is_year_start',
                                        'pandas.tseries.offsets.YearEnd': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.html#pandas.tseries.offsets.YearEnd',
                                        'pandas.tseries.offsets.YearEnd.copy': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.copy.html#pandas.tseries.offsets.YearEnd.copy',
                                        'pandas.tseries.offsets.YearEnd.is_anchored': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.is_anchored.html#pandas.tseries.offsets.YearEnd.is_anchored',
                                        'pandas.tseries.offsets.YearEnd.is_month_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.is_month_end.html#pandas.tseries.offsets.YearEnd.is_month_end',
                                        'pandas.tseries.offsets.YearEnd.is_month_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.is_month_start.html#pandas.tseries.offsets.YearEnd.is_month_start',
                                        'pandas.tseries.offsets.YearEnd.is_on_offset': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.is_on_offset.html#pandas.tseries.offsets.YearEnd.is_on_offset',
                                        'pandas.tseries.offsets.YearEnd.is_quarter_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.is_quarter_end.html#pandas.tseries.offsets.YearEnd.is_quarter_end',
                                        'pandas.tseries.offsets.YearEnd.is_quarter_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.is_quarter_start.html#pandas.tseries.offsets.YearEnd.is_quarter_start',
                                        'pandas.tseries.offsets.YearEnd.is_year_end': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.is_year_end.html#pandas.tseries.offsets.YearEnd.is_year_end',
                                        'pandas.tseries.offsets.YearEnd.is_year_start': 'https://pandas.pydata.org/docs/reference/api/pandas.tseries.offsets.YearEnd.is_year_start.html#pandas.tseries.offsets.YearEnd.is_year_start'},
            'pandas.util': { 'pandas.util.hash_array': 'https://pandas.pydata.org/docs/reference/api/pandas.util.hash_array.html#pandas.util.hash_array',
                             'pandas.util.hash_pandas_object': 'https://pandas.pydata.org/docs/reference/api/pandas.util.hash_pandas_object.html#pandas.util.hash_pandas_object'}}}
